@@ -220,7 +220,7 @@ void KateDocumentTest::testSetTextPerformance()
     QBENCHMARK {
         // init
         doc.setText(text);
-        for (const Range &range : qAsConst(ranges)) {
+        for (const Range &range : std::as_const(ranges)) {
             invalidator.addRange(doc.newMovingRange(range));
         }
         QCOMPARE(invalidator.ranges().size(), ranges.size());
@@ -441,7 +441,8 @@ void KateDocumentTest::testReplaceTabs()
     doc.paste(view, "\tHi");
     // ... and it still does not with indent-pasted on.
     // This behaviour is up to discussion.
-    QCOMPARE(doc.text(), QStringLiteral("int main() {\n    Hi\n}"));
+    // \t survives as we don't indent in the given case anymore, see 077dfe954699c674d2c34caf380199a4af7d184a
+    QCOMPARE(doc.text(), QStringLiteral("int main() {\n    \tHi\n}"));
 
     reset();
     doc.paste(view, "some\ncode\n  3\nhi");
@@ -490,7 +491,7 @@ void KateDocumentTest::testInsertNewline()
         "this is line2\n");
 
     SignalHandler handler;
-    connect(&doc, &KTextEditor::DocumentPrivate::textInserted, &handler, &SignalHandler::slotNewlineInserted);
+    connect(&doc, &KTextEditor::DocumentPrivate::textInsertedRange, &handler, &SignalHandler::slotNewlineInserted);
     doc.editWrapLine(1, 4);
 }
 
@@ -691,7 +692,7 @@ void KateDocumentTest::testSearch()
     KTextEditor::DocumentPrivate doc;
     doc.setText("foo\nbar\nzonk");
 
-    const QRegularExpression pattern(QStringLiteral("ar\nzonk$"), QRegularExpression::MultilineOption);
+    const QRegularExpression pattern(QStringLiteral("ar\nzonk$"), QRegularExpression::MultilineOption | QRegularExpression::UseUnicodePropertiesOption);
     int startLine = 0;
     int endLine = 2;
     QString textToMatch;
@@ -765,4 +766,89 @@ void KateDocumentTest::testMatchingBracket()
     QCOMPARE(doc.findMatchingBracket(cursor, maxLines), match);
 }
 
+void KateDocumentTest::testIndentOnPaste()
+{
+    KTextEditor::DocumentPrivate doc;
+    auto view = static_cast<KTextEditor::ViewPrivate *>(doc.createView(nullptr));
+
+    doc.setHighlightingMode("C++");
+    doc.config()->setTabWidth(4);
+    doc.config()->setIndentationMode("cppstyle");
+
+    doc.setConfigValue("indent-pasted-text", true);
+
+    /**
+     * namespace ns
+     * {
+     * class MyClass
+     */
+    doc.setText(QStringLiteral("namespace ns\n{\nclass MyClass"));
+    view->setCursorPosition({2, 5});
+    doc.paste(view, QStringLiteral(" SOME_MACRO"));
+    // We have text in the line we are pasting in so the existing indentation shouldn't be disturbed
+    QCOMPARE(doc.text(), QStringLiteral("namespace ns\n{\nclass SOME_MACRO MyClass"));
+
+    /**
+     * namespace ns
+     * {
+     */
+    doc.setText(QStringLiteral("namespace ns\n{\n"));
+    view->setCursorPosition({2, 0});
+    doc.paste(view, QStringLiteral("class MyClass"));
+    // We have no text in the line we are pasting in so indentation will be adjusted
+    QCOMPARE(doc.text(), QStringLiteral("namespace ns\n{\n    class MyClass"));
+}
+
+void KateDocumentTest::testAboutToSave()
+{
+    KTextEditor::DocumentPrivate doc;
+    const QString thisFile = QString::fromUtf8(__FILE__);
+    bool opened = doc.openUrl(QUrl::fromLocalFile(thisFile));
+
+    QVERIFY(opened);
+
+    QSignalSpy spy(&doc, &KTextEditor::DocumentPrivate::aboutToSave);
+    QSignalSpy savedSpy(&doc, &KTextEditor::DocumentPrivate::documentSavedOrUploaded);
+
+    doc.documentSave();
+
+    QVERIFY(spy.count() == 1 || spy.wait());
+    QVERIFY(savedSpy.count() == 1 || savedSpy.wait());
+}
+
+void KateDocumentTest::testKeepUndoOverReload()
+{
+    // create test document with some simple text
+    KTextEditor::DocumentPrivate doc;
+    const QString initialText = QStringLiteral("lala\ntest\nfoobar\n");
+    doc.setText(initialText);
+    QCOMPARE(doc.text(), initialText);
+
+    // now: do some editing
+    const QString insertedText = QStringLiteral("newfirstline\n");
+    doc.insertText(KTextEditor::Cursor(0, 0), insertedText);
+    QCOMPARE(doc.text(), insertedText + initialText);
+
+    // test undo/redo
+    doc.undo();
+    QCOMPARE(doc.text(), initialText);
+    doc.redo();
+    QCOMPARE(doc.text(), insertedText + initialText);
+
+    // save it to some local temporary file, for later reload
+    QTemporaryFile tmpFile;
+    tmpFile.open();
+    QVERIFY(doc.saveAs(QUrl::fromLocalFile(tmpFile.fileName())));
+
+    // first: try if normal reload works
+    QVERIFY(doc.documentReload());
+    QCOMPARE(doc.text(), insertedText + initialText);
+
+    // test undo/redo AFTER reload
+    doc.undo();
+    QCOMPARE(doc.text(), initialText);
+    doc.redo();
+    QCOMPARE(doc.text(), insertedText + initialText);
+}
+
 #include "katedocument_test.moc"
