@@ -3,7 +3,6 @@
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
-
 #include "config.h"
 #include "kateglobal.h"
 
@@ -11,12 +10,17 @@
 #include "katetextbuffer.h"
 #include "katetextloader.h"
 
+#include "katedocument.h"
+
 // this is unfortunate, but needed for performance
 #include "katepartdebug.h"
 #include "kateview.h"
 
+#include <KAuth/Action>
+#include <KAuth/ExecuteJob>
+
 #ifndef Q_OS_WIN
-#include <errno.h>
+#include <cerrno>
 #include <unistd.h>
 // sadly there seems to be no possibility in Qt to determine detailed error
 // codes about e.g. file open errors, so we need to resort to evaluating
@@ -83,7 +87,7 @@ TextBuffer::~TextBuffer()
     Q_ASSERT(m_ranges.empty());
 
     // clean out all cursors and lines, only cursors belonging to range will survive
-    for (TextBlock *block : qAsConst(m_blocks)) {
+    for (TextBlock *block : std::as_const(m_blocks)) {
         block->deleteBlockContent();
     }
 
@@ -119,7 +123,7 @@ void TextBuffer::clear()
     newBlock->appendLine(QString());
 
     // clean out all cursors and lines, either move them to newBlock or invalidate them, if belonging to a range
-    for (TextBlock *block : qAsConst(m_blocks)) {
+    for (TextBlock *block : std::as_const(m_blocks)) {
         block->clearBlockContent(newBlock);
     }
 
@@ -164,7 +168,7 @@ QString TextBuffer::text() const
     QString text;
 
     // combine all blocks
-    for (TextBlock *block : qAsConst(m_blocks)) {
+    for (TextBlock *block : std::as_const(m_blocks)) {
         block->text(text);
     }
 
@@ -190,8 +194,9 @@ bool TextBuffer::startEditing()
 
     // transaction has started
     Q_EMIT editingStarted();
-    if (m_document)
+    if (m_document) {
         Q_EMIT m_document->KTextEditor::Document::editingStarted(m_document);
+    }
 
     // first transaction started
     return true;
@@ -218,14 +223,15 @@ bool TextBuffer::finishEditing()
 
     // transaction has finished
     Q_EMIT editingFinished();
-    if (m_document)
+    if (m_document) {
         Q_EMIT m_document->KTextEditor::Document::editingFinished(m_document);
+    }
 
     // last transaction finished
     return true;
 }
 
-void TextBuffer::wrapLine(const KTextEditor::Cursor &position)
+void TextBuffer::wrapLine(const KTextEditor::Cursor position)
 {
     // debug output for REAL low-level debugging
     BUFFER_DEBUG << "wrapLine" << position;
@@ -262,8 +268,9 @@ void TextBuffer::wrapLine(const KTextEditor::Cursor &position)
 
     // emit signal about done change
     Q_EMIT lineWrapped(position);
-    if (m_document)
+    if (m_document) {
         Q_EMIT m_document->KTextEditor::Document::lineWrapped(m_document, position);
+    }
 }
 
 void TextBuffer::unwrapLine(int line)
@@ -314,11 +321,12 @@ void TextBuffer::unwrapLine(int line)
 
     // emit signal about done change
     Q_EMIT lineUnwrapped(line);
-    if (m_document)
+    if (m_document) {
         Q_EMIT m_document->KTextEditor::Document::lineUnwrapped(m_document, line);
+    }
 }
 
-void TextBuffer::insertText(const KTextEditor::Cursor &position, const QString &text)
+void TextBuffer::insertText(const KTextEditor::Cursor position, const QString &text)
 {
     // debug output for REAL low-level debugging
     BUFFER_DEBUG << "insertText" << position << text;
@@ -351,11 +359,12 @@ void TextBuffer::insertText(const KTextEditor::Cursor &position, const QString &
 
     // emit signal about done change
     Q_EMIT textInserted(position, text);
-    if (m_document)
+    if (m_document) {
         Q_EMIT m_document->KTextEditor::Document::textInserted(m_document, position, text);
+    }
 }
 
-void TextBuffer::removeText(const KTextEditor::Range &range)
+void TextBuffer::removeText(KTextEditor::Range range)
 {
     // debug output for REAL low-level debugging
     BUFFER_DEBUG << "removeText" << range;
@@ -396,8 +405,9 @@ void TextBuffer::removeText(const KTextEditor::Range &range)
 
     // emit signal about done change
     Q_EMIT textRemoved(range, text);
-    if (m_document)
+    if (m_document) {
         Q_EMIT m_document->KTextEditor::Document::textRemoved(m_document, range, text);
+    }
 }
 
 int TextBuffer::blockForLine(int line) const
@@ -587,7 +597,8 @@ bool TextBuffer::load(const QString &filename, bool &encodingErrors, bool &tooLo
         encodingErrors = false;
         while (!file.eof()) {
             // read line
-            int offset = 0, length = 0;
+            int offset = 0;
+            int length = 0;
             bool currentError = !file.readLine(offset, length);
             encodingErrors = encodingErrors || currentError;
 
@@ -600,8 +611,9 @@ bool TextBuffer::load(const QString &filename, bool &encodingErrors, bool &tooLo
             // get Unicode data for this line
             const QChar *unicodeData = file.unicode() + offset;
 
-            if (longestLineLoaded < length)
+            if (longestLineLoaded < length) {
                 longestLineLoaded = length;
+            }
 
             // split lines, if too large
             do {
@@ -741,9 +753,8 @@ bool TextBuffer::save(const QString &filename)
 
 bool TextBuffer::saveBuffer(const QString &filename, KCompressionDevice &saveFile)
 {
-    // construct stream + disable Unicode headers
+    // construct stream
     QTextStream stream(&saveFile);
-    stream.setCodec(QTextCodec::codecForName("UTF-16"));
 
     // set the correct codec
     stream.setCodec(m_textCodec);
@@ -786,6 +797,8 @@ bool TextBuffer::saveBuffer(const QString &filename, KCompressionDevice &saveFil
     }
 
     // flush stream
+    // TODO: QTextStream::flush only writes bytes when it contains text. This is a fine optimization for most cases, but this makes saving
+    // an empty file with the BOM set impossible (results to an empty file with 0 bytes, no BOM)
     stream.flush();
 
     // only finalize if stream status == OK
@@ -814,7 +827,7 @@ TextBuffer::SaveResult TextBuffer::saveBufferUnprivileged(const QString &filenam
 
     // construct correct filter device
     // we try to use the same compression as for opening
-    const KCompressionDevice::CompressionType type = KFilterDev::compressionTypeForMimeType(m_mimeTypeForFilterDev);
+    const KCompressionDevice::CompressionType type = KCompressionDevice::compressionTypeForMimeType(m_mimeTypeForFilterDev);
     QScopedPointer<KCompressionDevice> saveFile(new KCompressionDevice(filename, type));
 
     if (!saveFile->open(QIODevice::WriteOnly)) {
@@ -837,7 +850,7 @@ bool TextBuffer::saveBufferEscalated(const QString &filename)
 {
     // construct correct filter device
     // we try to use the same compression as for opening
-    const KCompressionDevice::CompressionType type = KFilterDev::compressionTypeForMimeType(m_mimeTypeForFilterDev);
+    const KCompressionDevice::CompressionType type = KCompressionDevice::compressionTypeForMimeType(m_mimeTypeForFilterDev);
     QScopedPointer<KCompressionDevice> saveFile(new KCompressionDevice(filename, type));
     uint ownerId = -2;
     uint groupId = -2;
@@ -922,7 +935,7 @@ bool TextBuffer::saveBufferEscalated(const QString &filename)
     return true;
 }
 
-void TextBuffer::notifyAboutRangeChange(KTextEditor::View *view, KTextEditor::LineRange lineRange, bool rangeWithAttribute)
+void TextBuffer::notifyAboutRangeChange(KTextEditor::View *view, KTextEditor::LineRange lineRange, bool needsRepaint)
 {
     // ignore calls if no document is around
     if (!m_document) {
@@ -939,13 +952,13 @@ void TextBuffer::notifyAboutRangeChange(KTextEditor::View *view, KTextEditor::Li
         }
 
         // notify view, it is really a kate view
-        static_cast<KTextEditor::ViewPrivate *>(curView)->notifyAboutRangeChange(lineRange, rangeWithAttribute);
+        static_cast<KTextEditor::ViewPrivate *>(curView)->notifyAboutRangeChange(lineRange, needsRepaint);
     }
 }
 
 void TextBuffer::markModifiedLinesAsSaved()
 {
-    for (TextBlock *block : qAsConst(m_blocks)) {
+    for (TextBlock *block : std::as_const(m_blocks)) {
         block->markModifiedLinesAsSaved();
     }
 }
