@@ -13,7 +13,7 @@
 #include <QString>
 
 // on the fly compression
-#include <KFilterDev>
+#include <KCompressionDevice>
 
 namespace Kate
 {
@@ -57,7 +57,7 @@ public:
         m_fileSize = testMime.size();
 
         // construct filter device
-        KCompressionDevice::CompressionType compressionType = KFilterDev::compressionTypeForMimeType(m_mimeType);
+        KCompressionDevice::CompressionType compressionType = KCompressionDevice::compressionTypeForMimeType(m_mimeType);
         m_file = new KCompressionDevice(filename, compressionType);
     }
 
@@ -93,7 +93,7 @@ public:
         // init the hash with the git header
         const QString header = QStringLiteral("blob %1").arg(m_fileSize);
         m_digest.reset();
-        m_digest.addData(header.toLatin1() + '\0');
+        m_digest.addData(QByteArray(header.toLatin1() + '\0'));
 
         // if already opened, close the file...
         if (m_file->isOpen()) {
@@ -179,6 +179,11 @@ public:
          * bug 272579
          */
         bool failedToConvertOnce = false;
+        /**
+         * keep track if we have found BOM so that failedToConvertOnce is not erroneously set to true
+         * BUG: 440359
+         */
+        bool bomPreviouslyFound = m_bomFound;
 
         /**
          * reading loop
@@ -205,19 +210,20 @@ public:
                             QByteArray bom(m_buffer.data(), qMin(16, c));
                             QTextCodec *codecForByteOrderMark = QTextCodec::codecForUtfText(bom, nullptr);
 
-                            // if codec != null, we found a BOM!
-                            if (codecForByteOrderMark) {
+                            // if codecForByteOrderMark != null, we found a BOM!
+                            // BUT we only capture BOM if no codec was set, or the BOM encodes the same codec as m_codec.
+                            // These additional checks are necessary so that the (coincidentally matching) BOM characters won't be eaten for non-UTF encodings
+                            // TODO: support BOMs for other encodings? (see e.g. https://en.wikipedia.org/wiki/Byte_order_mark#Byte_order_marks_by_encoding)
+                            if (codecForByteOrderMark && (!m_codec || codecForByteOrderMark->mibEnum() == m_codec->mibEnum())) {
                                 m_bomFound = true;
 
                                 // eat away the different boms!
-                                int mib = codecForByteOrderMark->mibEnum();
+                                const int mib = codecForByteOrderMark->mibEnum();
                                 if (mib == 106) { // utf8
                                     bomBytes = 3;
-                                }
-                                if (mib == 1013 || mib == 1014 || mib == 1015) { // utf16
+                                } else if (mib == 1013 || mib == 1014 || mib == 1015) { // utf16
                                     bomBytes = 2;
-                                }
-                                if (mib == 1017 || mib == 1018 || mib == 1019) { // utf32
+                                } else if (mib == 1017 || mib == 1018 || mib == 1019) { // utf32
                                     bomBytes = 4;
                                 }
                             }
@@ -297,7 +303,12 @@ public:
 
                 // empty? try again
                 if (m_position == m_text.length()) {
-                    failedToConvertOnce = true;
+                    if (!bomPreviouslyFound && m_bomFound) {
+                        // BOM was processed above, so we didn't fail to convert
+                        bomPreviouslyFound = true;
+                    } else {
+                        failedToConvertOnce = true;
+                    }
                     continue;
                 }
             }
