@@ -6,26 +6,85 @@
 
 #include "kateargumenthinttree.h"
 
-#include <QApplication>
-#include <QDesktopWidget>
-#include <QHeaderView>
-#include <QScrollBar>
-
 #include "expandingtree/expandingwidgetmodel.h"
 #include "kateargumenthintmodel.h"
 #include "katecompletiondelegate.h"
 #include "katecompletionwidget.h"
 #include "kateview.h"
+
+#include <QApplication>
+#include <QDesktopWidget>
+#include <QHeaderView>
 #include <QModelIndex>
+#include <QPainter>
+#include <QScrollBar>
+
+class ArgumentHintDelegate : public KateCompletionDelegate
+{
+public:
+    using KateCompletionDelegate::KateCompletionDelegate;
+
+protected:
+    bool editorEvent(QEvent *event, QAbstractItemModel *, const QStyleOptionViewItem &, const QModelIndex &index) override
+    {
+        if (event->type() == QEvent::MouseButtonRelease) {
+            event->accept();
+            model()->setExpanded(index, !model()->isExpanded(index));
+
+            return true;
+        } else {
+            event->ignore();
+        }
+
+        return false;
+    }
+
+    KateArgumentHintTree *tree() const
+    {
+        return static_cast<KateArgumentHintTree *>(parent());
+    }
+
+    KateArgumentHintModel *model() const
+    {
+        auto tree = this->tree();
+        return static_cast<KateArgumentHintModel *>(tree->model());
+    }
+
+    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override
+    {
+        QSize s = QStyledItemDelegate::sizeHint(option, index);
+        if (model()->isExpanded(index) && model()->expandingWidget(index)) {
+            QWidget *widget = model()->expandingWidget(index);
+            QSize widgetSize = widget->size();
+
+            s.setHeight(widgetSize.height() + s.height()
+                        + 10); // 10 is the sum that must match exactly the offsets used in ExpandingWidgetModel::placeExpandingWidget
+        }
+        return s;
+    }
+
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override
+    {
+        if (index.column() == 0) {
+            model()->placeExpandingWidget(index);
+        }
+        // paint the text at top if there is a widget below
+        m_alignTop = model()->isExpanded(index);
+
+        KateCompletionDelegate::paint(painter, option, index);
+    }
+};
 
 KateArgumentHintTree::KateArgumentHintTree(KateCompletionWidget *parent)
-    : ExpandingTree(nullptr)
+    : QTreeView(parent)
     , m_parent(parent) // Do not use the completion-widget as widget-parent, because the argument-hint-tree will be rendered separately
 {
-    setFrameStyle(QFrame::Box | QFrame::Plain);
+    setFrameStyle(QFrame::Box | QFrame::Raised);
     setLineWidth(1);
 
-    connect(parent, SIGNAL(destroyed(QObject *)), this, SLOT(deleteLater()));
+    setUniformRowHeights(false);
+    header()->setMinimumSectionSize(0);
+
     setFrameStyle(QFrame::NoFrame);
     setFrameStyle(QFrame::Box | QFrame::Plain);
     setFocusPolicy(Qt::NoFocus);
@@ -37,7 +96,7 @@ KateArgumentHintTree::KateArgumentHintTree(KateCompletionWidget *parent)
     setIndentation(0);
     setAllColumnsShowFocus(true);
     setAlternatingRowColors(true);
-    setItemDelegate(new KateCompletionDelegate(parent->argumentHintModel(), parent));
+    setItemDelegate(new ArgumentHintDelegate(this));
 }
 
 void KateArgumentHintTree::clearCompletion()
@@ -56,20 +115,6 @@ void KateArgumentHintTree::paintEvent(QPaintEvent *event)
     updateGeometry(); ///@todo delay this. It is needed here, because visualRect(...) returns an invalid rect in updateGeometry before the content is painted
 }
 
-void KateArgumentHintTree::dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QVector<int> &roles)
-{
-    Q_UNUSED(roles)
-    QTreeView::dataChanged(topLeft, bottomRight);
-    // updateGeometry();
-}
-
-void KateArgumentHintTree::currentChanged(const QModelIndex &current, const QModelIndex &previous)
-{
-    /*  qCDebug(LOG_KTE) << "currentChanged()";*/
-    static_cast<ExpandingWidgetModel *>(model())->rowSelected(current);
-    QTreeView::currentChanged(current, previous);
-}
-
 void KateArgumentHintTree::rowsInserted(const QModelIndex &parent, int start, int end)
 {
     QTreeView::rowsInserted(parent, start, end);
@@ -252,10 +297,11 @@ bool KateArgumentHintTree::pageDown()
 
     if (current.isValid()) {
         setCurrentIndex(current);
-        if (!model()->indexIsItem(current))
+        if (!model()->indexIsItem(current)) {
             if (!nextCompletion()) {
                 previousCompletion();
             }
+        }
     }
 
     return current != old;
@@ -268,10 +314,11 @@ bool KateArgumentHintTree::pageUp()
 
     if (current.isValid()) {
         setCurrentIndex(current);
-        if (!model()->indexIsItem(current))
+        if (!model()->indexIsItem(current)) {
             if (!previousCompletion()) {
                 nextCompletion();
             }
+        }
     }
     return current != old;
 }
