@@ -168,14 +168,9 @@ QVariant KateCompletionModel::data(const QModelIndex &index, int role) const
         return QVariant();
     }
 
-    if (role == Qt::DecorationRole && index.column() == KTextEditor::CodeCompletionModel::Prefix && isExpandable(index)) {
-        cacheIcons();
-
-        if (!isExpanded(index)) {
-            return QVariant(m_collapsedIcon);
-        } else {
-            return QVariant(m_expandedIcon);
-        }
+    if (role == InternalRole::IsNonEmptyGroup) {
+        auto group = groupForIndex(index);
+        return group && !group->isEmpty;
     }
 
     // groupOfParent returns a group when the index is a member of that group, but not the group head/label.
@@ -511,7 +506,6 @@ QModelIndex KateCompletionModel::indexForGroup(Group *g) const
 
 void KateCompletionModel::clearGroups()
 {
-    clearExpanding();
     m_ungrouped->clear();
     m_argumentHints->clear();
     m_bestMatches->clear();
@@ -1013,8 +1007,6 @@ void KateCompletionModel::setCurrentCompletion(KTextEditor::CodeCompletionModel
         endResetModel();
     }
 
-    clearExpanding(); // We need to do this, or be aware of expanding-widgets while filtering.
-
     Q_EMIT layoutChanged();
 }
 
@@ -2055,9 +2047,8 @@ void KateCompletionModel::updateBestMatches()
     hideOrShowGroup(m_bestMatches);
 }
 
-void KateCompletionModel::rowSelected(const QModelIndex &row)
+void KateCompletionModel::rowSelected(const QModelIndex & /*row*/)
 {
-    ExpandingWidgetModel::rowSelected(row);
     ///@todo delay this
     int rc = widget()->argumentHintModel()->rowCount(QModelIndex());
     if (rc == 0) {
