@@ -26,6 +26,7 @@ namespace KTextEditor
 {
 class ViewPrivate;
 }
+class DocTip;
 class KateCompletionModel;
 class KateCompletionTree;
 class KateArgumentHintTree;
@@ -51,10 +52,10 @@ public:
     bool isCompletionActive() const;
     void startCompletion(KTextEditor::CodeCompletionModel::InvocationType invocationType,
                          const QList<KTextEditor::CodeCompletionModel *> &models = QList<KTextEditor::CodeCompletionModel *>());
-    void startCompletion(const KTextEditor::Range &word,
+    void startCompletion(KTextEditor::Range word,
                          KTextEditor::CodeCompletionModel *model,
                          KTextEditor::CodeCompletionModel::InvocationType invocationType = KTextEditor::CodeCompletionModel::ManualInvocation);
-    void startCompletion(const KTextEditor::Range &word,
+    void startCompletion(KTextEditor::Range word,
                          const QList<KTextEditor::CodeCompletionModel *> &models = QList<KTextEditor::CodeCompletionModel *>(),
                          KTextEditor::CodeCompletionModel::InvocationType invocationType = KTextEditor::CodeCompletionModel::ManualInvocation);
     void userInvokedCompletion();
@@ -68,8 +69,7 @@ public Q_SLOTS:
 public:
     void tab(bool shift);
 
-    /// Returns whether the current item was expanded/unexpanded
-    bool toggleExpanded(bool forceExpand = false, bool forceUnExpand = false);
+    void toggleDocumentation();
 
     const KateCompletionModel *model() const;
     KateCompletionModel *model();
@@ -112,12 +112,6 @@ public:
 
     QWidget *currentEmbeddedWidget();
 
-    bool canExpandCurrentItem() const;
-
-    bool canCollapseCurrentItem() const;
-
-    void setCurrentItemExpanded(bool);
-
     // Returns true if a screen border has been hit
     bool updatePosition(bool force = false);
 
@@ -131,14 +125,16 @@ public:
 
     void updateHeight();
 
+    void showDocTip(const QModelIndex &idx);
+    DocTip *docTip() const
+    {
+        return m_docTip;
+    }
+
 public Q_SLOTS:
     void waitForModelReset();
 
     void abortCompletion();
-    void showConfig();
-    /*    void viewFocusIn();
-        void viewFocusOut();*/
-    void updatePositionSlot();
     void automaticInvocation();
 
     /*    void updateFocus();*/
@@ -151,9 +147,6 @@ public Q_SLOTS:
     bool navigateAccept();
     bool navigateBack();
 
-    bool hadNavigation() const;
-    void resetHadNavigation();
-
 protected:
     void showEvent(QShowEvent *event) override;
     void resizeEvent(QResizeEvent *event) override;
@@ -184,6 +177,8 @@ private:
     void switchList();
     void completionRangeChanged(KTextEditor::CodeCompletionModel *, const KTextEditor::Range &word);
 
+    QString tailString() const;
+
     void deleteCompletionRanges();
 
     QList<KTextEditor::CodeCompletionModel *> m_sourceModels;
@@ -197,22 +192,15 @@ private:
     KateCompletionTree *m_entryList;
     KateArgumentHintModel *m_argumentHintModel;
     KateArgumentHintTree *m_argumentHintTree;
+    DocTip *m_docTip;
 
     QTimer *m_automaticInvocationTimer;
-    // QTimer* m_updateFocusTimer;
-    QWidget *m_statusBar;
-    QToolButton *m_sortButton;
-    QLabel *m_sortText;
-    QToolButton *m_filterButton;
-    QLabel *m_filterText;
-    QPushButton *m_configButton;
 
     KTextEditor::Cursor m_automaticInvocationAt;
     QString m_automaticInvocationLine;
     int m_automaticInvocationDelay;
     bool m_filterInstalled;
 
-    class KateCompletionConfig *m_configWidget;
     bool m_lastInsertionByUser;
     bool m_inCompletionList; // Are we in the completion-list? If not, we're in the argument-hint list
     bool m_isSuspended;
@@ -231,6 +219,7 @@ private:
     bool m_completionEditRunning;
 
     int m_expandedAddedHeightBase;
+
     KTextEditor::CodeCompletionModel::InvocationType m_lastInvocationType;
 };
 
