@@ -49,12 +49,10 @@
 #include <KActionCollection>
 #include <KCharsets>
 #include <KColorCombo>
-#include <KFontChooser>
-#include <KLineEdit>
+#include <KFontRequester>
 #include <KMessageBox>
 #include <KProcess>
 #include <KSeparator>
-#include <KShortcutsDialog>
 
 #include <QCheckBox>
 #include <QClipboard>
@@ -104,6 +102,7 @@ KateIndentConfigTab::KateIndentConfigTab(QWidget *parent)
 
     reload();
 
+    observeChanges(ui->chkAutoDetectIndent);
     observeChanges(ui->chkBackspaceUnindents);
     observeChanges(ui->chkIndentPaste);
     observeChanges(ui->chkKeepExtraSpaces);
@@ -160,6 +159,7 @@ void KateIndentConfigTab::apply()
     KateDocumentConfig::global()->setKeepExtraSpaces(ui->chkKeepExtraSpaces->isChecked());
     KateDocumentConfig::global()->setReplaceTabsDyn(ui->rbIndentWithSpaces->isChecked());
     KateDocumentConfig::global()->setTabWidth(ui->sbTabWidth->value());
+    KateDocumentConfig::global()->setAutoDetectIndent(ui->chkAutoDetectIndent->isChecked());
 
     if (ui->rbTabAdvances->isChecked()) {
         KateDocumentConfig::global()->setTabHandling(KateDocumentConfig::tabInsertsTab);
@@ -178,6 +178,7 @@ void KateIndentConfigTab::reload()
     ui->chkIndentPaste->setChecked(KateDocumentConfig::global()->indentPastedText());
     ui->chkKeepExtraSpaces->setChecked(KateDocumentConfig::global()->keepExtraSpaces());
 
+    ui->chkAutoDetectIndent->setChecked(KateDocumentConfig::global()->autoDetectIndent());
     ui->sbIndentWidth->setSuffix(ki18np(" character", " characters"));
     ui->sbIndentWidth->setValue(KateDocumentConfig::global()->indentationWidth());
     ui->sbTabWidth->setSuffix(ki18np(" character", " characters"));
@@ -226,7 +227,9 @@ KateCompletionConfigTab::KateCompletionConfigTab(QWidget *parent)
     reload();
 
     observeChanges(ui->chkAutoCompletionEnabled);
+    observeChanges(ui->chkAutoSelectFirstEntry);
     observeChanges(ui->gbKeywordCompletion);
+    observeChanges(ui->gbShowDoc);
     observeChanges(ui->gbWordCompletion);
     observeChanges(ui->minimalWordLength);
     observeChanges(ui->removeTail);
@@ -255,10 +258,12 @@ void KateCompletionConfigTab::apply()
     KateViewConfig::global()->configStart();
 
     KateViewConfig::global()->setValue(KateViewConfig::AutomaticCompletionInvocation, ui->chkAutoCompletionEnabled->isChecked());
+    KateViewConfig::global()->setValue(KateViewConfig::AutomaticCompletionPreselectFirst, ui->chkAutoSelectFirstEntry->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::KeywordCompletion, ui->gbKeywordCompletion->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::WordCompletion, ui->gbWordCompletion->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::WordCompletionMinimalWordLength, ui->minimalWordLength->value());
     KateViewConfig::global()->setValue(KateViewConfig::WordCompletionRemoveTail, ui->removeTail->isChecked());
+    KateViewConfig::global()->setValue(KateViewConfig::ShowDocWithCompletion, ui->gbShowDoc->isChecked());
 
     KateViewConfig::global()->configEnd();
 }
@@ -266,9 +271,11 @@ void KateCompletionConfigTab::apply()
 void KateCompletionConfigTab::reload()
 {
     ui->chkAutoCompletionEnabled->setChecked(KateViewConfig::global()->automaticCompletionInvocation());
+    ui->chkAutoSelectFirstEntry->setChecked(KateViewConfig::global()->automaticCompletionPreselectFirst());
 
     ui->gbKeywordCompletion->setChecked(KateViewConfig::global()->keywordCompletion());
     ui->gbWordCompletion->setChecked(KateViewConfig::global()->wordCompletion());
+    ui->gbShowDoc->setChecked(KateViewConfig::global()->showDocWithCompletion());
 
     ui->minimalWordLength->setValue(KateViewConfig::global()->wordCompletionMinimalWordLength());
     ui->removeTail->setChecked(KateViewConfig::global()->wordCompletionRemoveTail());
@@ -370,6 +377,7 @@ KateNavigationConfigTab::KateNavigationConfigTab(QWidget *parent)
     observeChanges(ui->chkScrollPastEnd);
     observeChanges(ui->chkSmartHome);
     observeChanges(ui->sbAutoCenterCursor);
+    observeChanges(ui->chkCamelCursor);
 
     layout->addWidget(newWidget);
 }
@@ -392,6 +400,7 @@ void KateNavigationConfigTab::apply()
 
     KateDocumentConfig::global()->setPageUpDownMovesCursor(ui->chkPagingMovesCursor->isChecked());
     KateDocumentConfig::global()->setSmartHome(ui->chkSmartHome->isChecked());
+    KateDocumentConfig::global()->setCamelCursor(ui->chkCamelCursor->isChecked());
 
     KateViewConfig::global()->setValue(KateViewConfig::AutoCenterLines, ui->sbAutoCenterCursor->value());
     KateViewConfig::global()->setValue(KateViewConfig::BackspaceRemoveComposedCharacters, ui->chkBackspaceRemoveComposed->isChecked());
@@ -410,6 +419,7 @@ void KateNavigationConfigTab::reload()
     ui->chkPagingMovesCursor->setChecked(KateDocumentConfig::global()->pageUpDownMovesCursor());
     ui->chkScrollPastEnd->setChecked(KateViewConfig::global()->scrollPastEnd());
     ui->chkSmartHome->setChecked(KateDocumentConfig::global()->smartHome());
+    ui->chkCamelCursor->setChecked(KateDocumentConfig::global()->camelCursor());
 
     ui->sbAutoCenterCursor->setValue(KateViewConfig::global()->autoCenterLines());
 }
@@ -430,8 +440,7 @@ KateEditGeneralConfigTab::KateEditGeneralConfigTab(QWidget *parent)
     ui = new Ui::EditConfigWidget();
     ui->setupUi(newWidget);
 
-    const QList<KateAbstractInputModeFactory *> inputModes = KTextEditor::EditorPrivate::self()->inputModeFactories();
-    for (KateAbstractInputModeFactory *fact : inputModes) {
+    for (const auto &fact : KTextEditor::EditorPrivate::self()->inputModeFactories()) {
         ui->cmbInputMode->addItem(fact->name(), static_cast<int>(fact->inputMode()));
     }
 
@@ -446,6 +455,7 @@ KateEditGeneralConfigTab::KateEditGeneralConfigTab(QWidget *parent)
     observeChanges(ui->chkSmartCopyCut);
     observeChanges(ui->chkStaticWordWrap);
     observeChanges(ui->cmbEncloseSelection);
+    ui->lblBracketHelp->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
     connect(ui->cmbEncloseSelection->lineEdit(), &QLineEdit::editingFinished, [=] {
         const int index = ui->cmbEncloseSelection->currentIndex();
         const QString text = ui->cmbEncloseSelection->currentText();
@@ -523,7 +533,7 @@ void KateEditGeneralConfigTab::reload()
     ui->cmbEncloseSelection->setItemData(0, i18n("Disable Feature"), Qt::ToolTipRole);
     ui->cmbEncloseSelection->addItem(QStringLiteral("`*_~"), MarkDown);
     ui->cmbEncloseSelection->setItemData(1, i18n("May be handy with Markdown"), Qt::ToolTipRole);
-    ui->cmbEncloseSelection->addItem(QStringLiteral("<>(){}[]"), MirrorChar);
+    ui->cmbEncloseSelection->addItem(QStringLiteral("<>(){}[]'\""), MirrorChar);
     ui->cmbEncloseSelection->setItemData(2, i18n("Mirror characters, similar but not exactly like auto brackets"), Qt::ToolTipRole);
     ui->cmbEncloseSelection->addItem(QStringLiteral("´`_.:|#@~*!?$%/=,;-+^°§&"), NonLetters);
     ui->cmbEncloseSelection->setItemData(3, i18n("Non letter character"), Qt::ToolTipRole);
@@ -571,8 +581,7 @@ KateEditConfigTab::KateEditConfigTab(QWidget *parent)
     observeChanges(spellCheckConfigTab);
 
     int i = tabWidget->count();
-    const auto inputModeFactories = KTextEditor::EditorPrivate::self()->inputModeFactories();
-    for (KateAbstractInputModeFactory *factory : inputModeFactories) {
+    for (const auto &factory : KTextEditor::EditorPrivate::self()->inputModeFactories()) {
         KateConfigPage *tab = factory->createConfigPage(this);
         if (tab) {
             m_inputModeConfigTabs << tab;
@@ -598,7 +607,7 @@ void KateEditConfigTab::apply()
     indentConfigTab->apply();
     completionConfigTab->apply();
     spellCheckConfigTab->apply();
-    for (KateConfigPage *tab : qAsConst(m_inputModeConfigTabs)) {
+    for (KateConfigPage *tab : std::as_const(m_inputModeConfigTabs)) {
         tab->apply();
     }
 }
@@ -610,7 +619,7 @@ void KateEditConfigTab::reload()
     indentConfigTab->reload();
     completionConfigTab->reload();
     spellCheckConfigTab->reload();
-    for (KateConfigPage *tab : qAsConst(m_inputModeConfigTabs)) {
+    for (KateConfigPage *tab : std::as_const(m_inputModeConfigTabs)) {
         tab->reload();
     }
 }
@@ -622,7 +631,7 @@ void KateEditConfigTab::reset()
     indentConfigTab->reset();
     completionConfigTab->reset();
     spellCheckConfigTab->reset();
-    for (KateConfigPage *tab : qAsConst(m_inputModeConfigTabs)) {
+    for (KateConfigPage *tab : std::as_const(m_inputModeConfigTabs)) {
         tab->reset();
     }
 }
@@ -634,7 +643,7 @@ void KateEditConfigTab::defaults()
     indentConfigTab->defaults();
     completionConfigTab->defaults();
     spellCheckConfigTab->defaults();
-    for (KateConfigPage *tab : qAsConst(m_inputModeConfigTabs)) {
+    for (KateConfigPage *tab : std::as_const(m_inputModeConfigTabs)) {
         tab->defaults();
     }
 }
@@ -667,12 +676,6 @@ KateViewDefaultsConfig::KateViewDefaultsConfig(QWidget *parent)
     layout->addWidget(tabWidget);
     layout->setContentsMargins(0, 0, 0, 0);
 
-    QWidget *fontTab = new QWidget(tabWidget);
-    QGridLayout *grid = new QGridLayout(fontTab);
-    m_fontchooser = new KFontChooser(fontTab, KFontChooser::NoDisplayFlags);
-    grid->addWidget(m_fontchooser, 0, 0);
-    tabWidget->addTab(fontTab, i18n("Font"));
-
     QWidget *textareaTab = new QWidget(tabWidget);
     textareaUi->setupUi(textareaTab);
     tabWidget->addTab(textareaTab, i18n("General"));
@@ -689,7 +692,7 @@ KateViewDefaultsConfig::KateViewDefaultsConfig(QWidget *parent)
 
     reload();
 
-    observeChanges(m_fontchooser);
+    observeChanges(textareaUi->kfontrequester);
 
     observeChanges(textareaUi->chkAnimateBracketMatching);
     observeChanges(textareaUi->chkDynWrapAnywhere);
@@ -702,7 +705,22 @@ KateViewDefaultsConfig::KateViewDefaultsConfig(QWidget *parent)
     observeChanges(textareaUi->chkShowWholeBracketExpression);
     observeChanges(textareaUi->chkShowWordCount);
     observeChanges(textareaUi->cmbDynamicWordWrapIndicator);
-    observeChanges(textareaUi->gbWordWrap);
+    observeChanges(textareaUi->cbxWordWrap);
+    observeChanges(textareaUi->chkFocusFrame);
+    auto a = [ui = textareaUi, cbx = textareaUi->cbxWordWrap]() {
+        ui->chkDynWrapAtStaticMarker->setEnabled(cbx->isChecked());
+        ui->chkDynWrapAnywhere->setEnabled(cbx->isChecked());
+        ui->cmbDynamicWordWrapIndicator->setEnabled(cbx->isChecked());
+        ui->sbDynamicWordWrapDepth->setEnabled(cbx->isChecked());
+    };
+    connect(textareaUi->cbxWordWrap, &QCheckBox::stateChanged, this, a);
+    a();
+    auto b = [cbx = textareaUi->cbxIndentWrappedLines, sb = textareaUi->sbDynamicWordWrapDepth]() {
+        sb->setEnabled(cbx->isChecked());
+    };
+    b();
+    connect(textareaUi->cbxIndentWrappedLines, &QCheckBox::stateChanged, this, b);
+    observeChanges(textareaUi->cbxIndentWrappedLines);
     observeChanges(textareaUi->sbDynamicWordWrapDepth);
     observeChanges(textareaUi->sliSetMarkerSize);
     observeChanges(textareaUi->spacesComboBox);
@@ -744,21 +762,26 @@ void KateViewDefaultsConfig::apply()
     KateDocumentConfig::global()->setShowSpaces(KateDocumentConfig::WhitespaceRendering(textareaUi->spacesComboBox->currentIndex()));
     KateDocumentConfig::global()->setShowTabs(textareaUi->chkShowTabs->isChecked());
 
-    KateRendererConfig::global()->setFont(m_fontchooser->font());
+    KateRendererConfig::global()->setFont(textareaUi->kfontrequester->font());
     KateRendererConfig::global()->setAnimateBracketMatching(textareaUi->chkAnimateBracketMatching->isChecked());
     KateRendererConfig::global()->setShowIndentationLines(textareaUi->chkShowIndentationLines->isChecked());
     KateRendererConfig::global()->setShowWholeBracketExpression(textareaUi->chkShowWholeBracketExpression->isChecked());
 
-    KateViewConfig::global()->setDynWordWrap(textareaUi->gbWordWrap->isChecked());
+    KateViewConfig::global()->setDynWordWrap(textareaUi->cbxWordWrap->isChecked());
     KateViewConfig::global()->setShowWordCount(textareaUi->chkShowWordCount->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::BookmarkSorting, bordersUi->rbSortBookmarksByPosition->isChecked() ? 0 : 1);
-    KateViewConfig::global()->setValue(KateViewConfig::DynWordWrapAlignIndent, textareaUi->sbDynamicWordWrapDepth->value());
+    if (!textareaUi->cbxIndentWrappedLines->isChecked()) {
+        KateViewConfig::global()->setValue(KateViewConfig::DynWordWrapAlignIndent, 0);
+    } else {
+        KateViewConfig::global()->setValue(KateViewConfig::DynWordWrapAlignIndent, textareaUi->sbDynamicWordWrapDepth->value());
+    }
     KateViewConfig::global()->setValue(KateViewConfig::DynWordWrapIndicators, textareaUi->cmbDynamicWordWrapIndicator->currentIndex());
     KateViewConfig::global()->setValue(KateViewConfig::DynWrapAnywhere, textareaUi->chkDynWrapAnywhere->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::DynWrapAtStaticMarker, textareaUi->chkDynWrapAtStaticMarker->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::FoldFirstLine, textareaUi->chkFoldFirstLine->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::ScrollBarMiniMapWidth, bordersUi->spBoxMiniMapWidth->value());
     KateViewConfig::global()->setValue(KateViewConfig::ShowBracketMatchPreview, textareaUi->chkShowBracketMatchPreview->isChecked());
+    KateViewConfig::global()->setValue(KateViewConfig::ShowFocusFrame, textareaUi->chkFocusFrame->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::ShowFoldingBar, bordersUi->chkShowFoldingMarkers->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::ShowFoldingPreview, bordersUi->chkShowFoldingPreview->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::ShowIconBar, bordersUi->chkIconBorder->isChecked());
@@ -791,7 +814,7 @@ void KateViewDefaultsConfig::reload()
     bordersUi->rbSortBookmarksByPosition->setChecked(KateViewConfig::global()->bookmarkSort() == 0);
     bordersUi->spBoxMiniMapWidth->setValue(KateViewConfig::global()->scrollBarMiniMapWidth());
 
-    m_fontchooser->setFont(KateRendererConfig::global()->baseFont());
+    textareaUi->kfontrequester->setFont(KateRendererConfig::global()->baseFont());
 
     textareaUi->chkAnimateBracketMatching->setChecked(KateRendererConfig::global()->animateBracketMatching());
     textareaUi->chkDynWrapAnywhere->setChecked(KateViewConfig::global()->dynWrapAnywhere());
@@ -804,10 +827,12 @@ void KateViewDefaultsConfig::reload()
     textareaUi->chkShowWholeBracketExpression->setChecked(KateRendererConfig::global()->showWholeBracketExpression());
     textareaUi->chkShowWordCount->setChecked(KateViewConfig::global()->showWordCount());
     textareaUi->cmbDynamicWordWrapIndicator->setCurrentIndex(KateViewConfig::global()->dynWordWrapIndicators());
-    textareaUi->gbWordWrap->setChecked(KateViewConfig::global()->dynWordWrap());
+    textareaUi->cbxWordWrap->setChecked(KateViewConfig::global()->dynWordWrap());
+    textareaUi->cbxIndentWrappedLines->setChecked(KateViewConfig::global()->dynWordWrapAlignIndent() != 0);
     textareaUi->sbDynamicWordWrapDepth->setValue(KateViewConfig::global()->dynWordWrapAlignIndent());
     textareaUi->sliSetMarkerSize->setValue(KateDocumentConfig::global()->markerSize());
     textareaUi->spacesComboBox->setCurrentIndex(KateDocumentConfig::global()->showSpaces());
+    textareaUi->chkFocusFrame->setChecked(KateViewConfig::global()->showFocusFrame());
 }
 
 void KateViewDefaultsConfig::reset()
@@ -858,6 +883,8 @@ KateSaveConfigTab::KateSaveConfigTab(QWidget *parent)
     QWidget *newWidget2 = new QWidget(tabWidget);
     uiadv = new Ui::OpenSaveConfigAdvWidget();
     uiadv->setupUi(newWidget2);
+    uiadv->lblExplanatory->setText(i18n("%1 backs up unsaved files to \"swap files.\" Swap files allow %1 to recover your work in the case of a system crash. Disabling swap files may cause data loss in case of a system crash.", QCoreApplication::applicationName()));
+    uiadv->lblExplanatory->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
 
     // "What's This?" help can be found in the ui file
 
@@ -876,7 +903,7 @@ KateSaveConfigTab::KateSaveConfigTab(QWidget *parent)
     observeChanges(uiadv->chkBackupLocalFiles);
     observeChanges(uiadv->chkBackupRemoteFiles);
     observeChanges(uiadv->cmbSwapFileMode);
-    connect(uiadv->cmbSwapFileMode, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &KateSaveConfigTab::swapFileModeChanged);
+    connect(uiadv->cmbSwapFileMode, qOverload<int>(&QComboBox::currentIndexChanged), this, &KateSaveConfigTab::swapFileModeChanged);
 
     observeChanges(uiadv->edtBackupPrefix);
     observeChanges(uiadv->edtBackupSuffix);
@@ -910,6 +937,7 @@ KateSaveConfigTab::KateSaveConfigTab(QWidget *parent)
 
 KateSaveConfigTab::~KateSaveConfigTab()
 {
+    delete uiadv;
     delete ui;
 }
 
@@ -1184,8 +1212,8 @@ bool KateGotoBar::eventFilter(QObject *object, QEvent *event)
 
 void KateGotoBar::gotoClipboard()
 {
-    QRegularExpression rx(QStringLiteral("-?\\d+"));
-    int lineNo = rx.match(QApplication::clipboard()->text(QClipboard::Selection)).captured().toInt();
+    static const QRegularExpression rx(QStringLiteral("-?\\d+"));
+    const int lineNo = rx.match(QApplication::clipboard()->text(QClipboard::Selection)).captured().toInt();
     if (lineNo >= m_gotoRange->minimum() && lineNo <= m_gotoRange->maximum()) {
         m_gotoRange->setValue(lineNo);
         gotoLine();
@@ -1237,7 +1265,7 @@ void KateGotoBar::gotoLine()
 
     m_view->setCursorPosition(KTextEditor::Cursor(gotoValue, 0));
     m_view->setFocus();
-    emit hideMe();
+    Q_EMIT hideMe();
 }
 // END KateGotoBar
 
@@ -1252,8 +1280,8 @@ KateDictionaryBar::KateDictionaryBar(KTextEditor::ViewPrivate *view, QWidget *pa
     topLayout->setContentsMargins(0, 0, 0, 0);
     // topLayout->setSpacing(spacingHint());
     m_dictionaryComboBox = new Sonnet::DictionaryComboBox(centralWidget());
-    connect(m_dictionaryComboBox, SIGNAL(dictionaryChanged(QString)), this, SLOT(dictionaryChanged(QString)));
-    connect(view->doc(), SIGNAL(defaultDictionaryChanged(KTextEditor::DocumentPrivate *)), this, SLOT(updateData()));
+    connect(m_dictionaryComboBox, &Sonnet::DictionaryComboBox::dictionaryChanged, this, &KateDictionaryBar::dictionaryChanged);
+    connect(view->doc(), &KTextEditor::DocumentPrivate::defaultDictionaryChanged, this, &KateDictionaryBar::updateData);
     QLabel *label = new QLabel(i18n("Dictionary:"), centralWidget());
     label->setBuddy(m_dictionaryComboBox);
 
@@ -1295,6 +1323,7 @@ KateModOnHdPrompt::KateModOnHdPrompt(KTextEditor::DocumentPrivate *doc, KTextEdi
     : QObject(doc)
     , m_doc(doc)
     , m_modtype(modtype)
+    , m_fullDiffPath(QStandardPaths::findExecutable(QStringLiteral("diff")))
     , m_proc(nullptr)
     , m_diffFile(nullptr)
     , m_diffAction(nullptr)
@@ -1312,19 +1341,19 @@ KateModOnHdPrompt::KateModOnHdPrompt(KTextEditor::DocumentPrivate *doc, KTextEdi
         m_message->addAction(aAutoReload, false);
         connect(aAutoReload, &QAction::triggered, this, &KateModOnHdPrompt::autoReloadTriggered);
 
-        if (!QStandardPaths::findExecutable(QStringLiteral("diff")).isEmpty()) {
+        if (!m_fullDiffPath.isEmpty()) {
             m_diffAction = new QAction(i18n("View &Difference"), this);
             m_diffAction->setIcon(QIcon::fromTheme(QStringLiteral("document-multiple")));
             m_diffAction->setToolTip(i18n("Shows a diff of the changes"));
             m_message->addAction(m_diffAction, false);
-            connect(m_diffAction, SIGNAL(triggered()), this, SLOT(slotDiff()));
+            connect(m_diffAction, &QAction::triggered, this, &KateModOnHdPrompt::slotDiff);
         }
 
         QAction *aReload = new QAction(i18n("&Reload"), this);
         aReload->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
         aReload->setToolTip(i18n("Reload the file from disk. Unsaved changes will be lost."));
         m_message->addAction(aReload);
-        connect(aReload, SIGNAL(triggered()), this, SIGNAL(reloadTriggered()));
+        connect(aReload, &QAction::triggered, this, &KateModOnHdPrompt::reloadTriggered);
     } else {
         QAction *closeFile = new QAction(i18nc("@action:button closes the opened file", "&Close File"), this);
         closeFile->setIcon(QIcon::fromTheme(QStringLiteral("document-close")));
@@ -1336,14 +1365,14 @@ KateModOnHdPrompt::KateModOnHdPrompt(KTextEditor::DocumentPrivate *doc, KTextEdi
         aSaveAs->setIcon(QIcon::fromTheme(QStringLiteral("document-save-as")));
         aSaveAs->setToolTip(i18n("Lets you select a location and save the file again."));
         m_message->addAction(aSaveAs, false);
-        connect(aSaveAs, SIGNAL(triggered()), this, SIGNAL(saveAsTriggered()));
+        connect(aSaveAs, &QAction::triggered, this, &KateModOnHdPrompt::saveAsTriggered);
     }
 
     QAction *aIgnore = new QAction(i18n("&Ignore"), this);
     aIgnore->setToolTip(i18n("Ignores the changes on disk without any action."));
     aIgnore->setIcon(QIcon::fromTheme(QStringLiteral("dialog-cancel")));
     m_message->addAction(aIgnore);
-    connect(aIgnore, SIGNAL(triggered()), this, SIGNAL(ignoreTriggered()));
+    connect(aIgnore, &QAction::triggered, this, &KateModOnHdPrompt::ignoreTriggered);
 
     m_doc->postMessage(m_message);
 }
@@ -1366,15 +1395,15 @@ void KateModOnHdPrompt::slotDiff()
         return;
     }
 
-    m_diffFile = new QTemporaryFile(QLatin1String("XXXXXX.diff"));
+    m_diffFile = new QTemporaryFile(QDir::temp().filePath(QLatin1String("XXXXXX.diff")));
     m_diffFile->open();
 
     // Start a KProcess that creates a diff
     m_proc = new KProcess(this);
     m_proc->setOutputChannelMode(KProcess::MergedChannels);
-    *m_proc << QStringLiteral("diff") << QStringLiteral("-u") << QStringLiteral("-") << m_doc->url().toLocalFile();
-    connect(m_proc, SIGNAL(readyRead()), this, SLOT(slotDataAvailable()));
-    connect(m_proc, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(slotPDone()));
+    *m_proc << m_fullDiffPath << QStringLiteral("-u") << QStringLiteral("-") << m_doc->url().toLocalFile();
+    connect(m_proc, &KProcess::readyRead, this, &KateModOnHdPrompt::slotDataAvailable);
+    connect(m_proc, &KProcess::finished, this, &KateModOnHdPrompt::slotPDone);
 
     // disable the diff button, to hinder the user to run it twice.
     m_diffAction->setEnabled(false);
