@@ -13,9 +13,9 @@
 #include "kateglobal.h"
 #include "katehighlight.h"
 #include "katepartdebug.h"
+#include "katesyntaxmanager.h"
 
 #include <KCharsets>
-#include <KFilterDev>
 #include <KLocalizedString>
 
 #include <QDate>
@@ -97,8 +97,9 @@ void KateBuffer::updateHighlighting()
     // one line up, to e.g. get notified about new folding starts
     // see bug 351496
     int editTagLineStart = editingMinimalLineChanged();
-    if ((editTagLineStart > 0) && m_highlight->foldingIndentationSensitive())
+    if ((editTagLineStart > 0) && m_highlight->foldingIndentationSensitive()) {
         --editTagLineStart;
+    }
 
     // really update highlighting
     doHighlight(editTagLineStart, editTagLineEnd, true);
@@ -143,7 +144,9 @@ bool KateBuffer::openFile(const QString &m_file, bool enforceTextCodec)
     // will allow to do "kate newfile.txt" without error messages but still fail if e.g. you mistype a url
     // and it can't be fetched via fish:// or other strange things in kio happen...
     // just clear() + exit with success!
-    if (m_doc->url().isLocalFile() && !QFile::exists(m_file)) {
+
+    QFileInfo fileInfo(m_file);
+    if (m_doc->url().isLocalFile() && !fileInfo.exists()) {
         clear();
         KTextEditor::Message *message = new KTextEditor::Message(i18nc("short translation, user created new file", "New file"), KTextEditor::Message::Warning);
         message->setPosition(KTextEditor::Message::TopInView);
@@ -158,7 +161,7 @@ bool KateBuffer::openFile(const QString &m_file, bool enforceTextCodec)
 
     // check if this is a normal file or not, avoids to open char devices or directories!
     // else clear buffer and break out with error
-    if (!QFileInfo(m_file).isFile()) {
+    if (!fileInfo.isFile()) {
         clear();
         return false;
     }
@@ -195,9 +198,9 @@ bool KateBuffer::canEncode()
     }
 
     for (int i = 0; i < lines(); i++) {
-        if (!codec->canEncode(line(i)->string())) {
+        if (!codec->canEncode(line(i)->text())) {
             qCDebug(LOG_KTE) << QLatin1String("ENC NAME: ") << codec->name();
-            qCDebug(LOG_KTE) << QLatin1String("STRING LINE: ") << line(i)->string();
+            qCDebug(LOG_KTE) << QLatin1String("STRING LINE: ") << line(i)->text();
             qCDebug(LOG_KTE) << QLatin1String("ENC WORKING: FALSE");
 
             return false;
@@ -256,7 +259,7 @@ void KateBuffer::ensureHighlighted(int line, int lookAhead)
     doHighlight(m_lineHighlighted, end, false);
 }
 
-void KateBuffer::wrapLine(const KTextEditor::Cursor &position)
+void KateBuffer::wrapLine(const KTextEditor::Cursor position)
 {
     // call original
     Kate::TextBuffer::wrapLine(position);
