@@ -121,6 +121,11 @@ bool KateRenderer::showIndentLines() const
 
 void KateRenderer::setShowIndentLines(bool showIndentLines)
 {
+    // invalidate our "active indent line" cached stuff
+    m_currentBracketRange = KTextEditor::Range::invalid();
+    m_currentOpenBracketX = -1;
+    m_currentCloseBracketX = -1;
+
     m_config->setShowIndentationLines(showIndentLines);
 }
 
@@ -183,7 +188,10 @@ void KateRenderer::paintTextLineBackground(QPainter &paint, KateLineLayoutPtr la
     QColor currentLineColor = config()->highlightedLineColor();
 
     // Check for mark background
-    int markRed = 0, markGreen = 0, markBlue = 0, markCount = 0;
+    int markRed = 0;
+    int markGreen = 0;
+    int markBlue = 0;
+    int markCount = 0;
 
     // Retrieve marks for this line
     uint mrk = m_doc->mark(layout->line());
@@ -314,12 +322,96 @@ void KateRenderer::paintNonPrintableSpaces(QPainter &paint, qreal x, qreal y, co
     paint.restore();
 }
 
-void KateRenderer::paintIndentMarker(QPainter &paint, uint x)
+/**
+ * Helper function that checks if our cursor is at a bracket
+ * and calculates X position for opening/closing brackets. We
+ * then use this data to color the indentation line differently.
+ * @p view is current view
+ * @p range is the current range from @ref paintTextLine
+ * @p c is the position of cursor
+ * @p openX will be X position of open bracket or -1 if not found
+ * @p closeX will be X position of close bracket or -1 if not found
+ */
+static KTextEditor::Range cursorAtBracket(KTextEditor::ViewPrivate *view, const KateLineLayoutPtr &range, KTextEditor::Cursor c, int &openX, int &closeX)
 {
-    QPen penBackup(paint.pen());
-    QPen myPen(config()->indentationLineColor());
+    if (range->line() != c.line()) {
+        openX = closeX = -1;
+        return KTextEditor::Range::invalid();
+    }
+
+    auto *doc = view->doc();
+    // Avoid work if we are below tabwidth
+    if (c.column() < doc->config()->tabWidth()) {
+        openX = closeX = -1;
+        return KTextEditor::Range::invalid();
+    }
+
+    // We match these brackets only
+    static constexpr QChar brackets[] = {QLatin1Char('{'), QLatin1Char('}')};
+    // look for character in front
+    QChar right = doc->characterAt(c);
+    auto it = std::find(std::begin(brackets), std::end(brackets), right);
+
+    KTextEditor::Range ret = KTextEditor::Range::invalid();
+    bool inFront = false;
+    bool found = false;
+    if (it != std::end(brackets)) {
+        found = true;
+        inFront = true;
+    } else {
+        // look at previous character
+        QChar left = doc->characterAt({c.line(), c.column() - 1});
+        it = std::find(std::begin(brackets), std::end(brackets), left);
+        if (it != std::end(brackets)) {
+            found = true;
+            inFront = false;
+        }
+    }
+
+    // We have a bracket
+    if (found) {
+        ret = doc->findMatchingBracket(c, 150);
+        if (!ret.isValid()) {
+            openX = closeX = -1;
+            return ret;
+        }
+        // line for current pos
+        QTextLine line = range->layout()->lineForTextPosition(qMin(c.column(), range->length()));
+
+        if (ret.start().line() == c.line()) {
+            // Our cursor is at opening bracket
+            openX = line.cursorToX(c.column() + (inFront ? 0 : -1)) + 1;
+            QTextLine closeLine = view->textLayout(ret.end().line())->lineForTextPosition(ret.end().column());
+            closeX = closeLine.cursorToX(ret.end().column()) + 1;
+        } else {
+            // Our cursor is at closing bracket
+            closeX = line.cursorToX(c.column() + (inFront ? 0 : -1)) + 1;
+            QTextLine closeLine = view->textLayout(ret.start().line())->lineForTextPosition(ret.start().column());
+            openX = closeLine.cursorToX(ret.start().column()) + 1;
+        }
+    } else {
+        openX = closeX = -1;
+    }
+
+    return ret;
+}
+
+void KateRenderer::paintIndentMarker(QPainter &paint, uint x, int line)
+{
+    const QPen penBackup(paint.pen());
     static const QVector<qreal> dashPattern = QVector<qreal>() << 1 << 1;
-    myPen.setDashPattern(dashPattern);
+    QPen myPen;
+
+    const bool onBracket = m_currentOpenBracketX == (int)x || m_currentCloseBracketX == (int)x;
+    if (onBracket && m_currentBracketRange.containsLine(line)) {
+        QColor c = view()->theme().textColor(KSyntaxHighlighting::Theme::Normal);
+        c.setAlphaF(0.7);
+        myPen.setColor(c);
+    } else {
+        myPen.setColor(config()->indentationLineColor());
+        myPen.setDashPattern(dashPattern);
+    }
+
     paint.setPen(myPen);
 
     QPainter::RenderHints renderHints = paint.renderHints();
@@ -355,8 +447,7 @@ static bool rangeLessThanForRenderer(const Kate::TextRange *a, const Kate::TextR
     return false;
 }
 
-QVector<QTextLayout::FormatRange>
-KateRenderer::decorationsForLine(const Kate::TextLine &textLine, int line, bool selectionsOnly, bool completionHighlight, bool completionSelected) const
+QVector<QTextLayout::FormatRange> KateRenderer::decorationsForLine(const Kate::TextLine &textLine, int line, bool selectionsOnly) const
 {
     // limit number of attributes we can highlight in reasonable time
     const int limitOfRanges = 1024;
@@ -375,54 +466,52 @@ KateRenderer::decorationsForLine(const Kate::TextLine &textLine, int line, bool
     RenderRangeVector renderRanges;
     if (!al.isEmpty()) {
         auto &currentRange = renderRanges.pushNewRange();
-        for (int i = 0; i < std::min(al.count(), limitOfRanges); ++i) {
+        for (int i = 0; i < std::min<int>(al.count(), limitOfRanges); ++i) {
             if (al[i].length > 0 && al[i].attributeValue > 0) {
                 currentRange.addRange(KTextEditor::Range(KTextEditor::Cursor(line, al[i].offset), al[i].length), specificAttribute(al[i].attributeValue));
             }
         }
     }
 
-    if (!completionHighlight) {
-        // check for dynamic hl stuff
-        const QSet<Kate::TextRange *> *rangesMouseIn = m_view ? m_view->rangesMouseIn() : nullptr;
-        const QSet<Kate::TextRange *> *rangesCaretIn = m_view ? m_view->rangesCaretIn() : nullptr;
-        bool anyDynamicHlsActive = m_view && (!rangesMouseIn->empty() || !rangesCaretIn->empty());
+    // check for dynamic hl stuff
+    const QSet<Kate::TextRange *> *rangesMouseIn = m_view ? m_view->rangesMouseIn() : nullptr;
+    const QSet<Kate::TextRange *> *rangesCaretIn = m_view ? m_view->rangesCaretIn() : nullptr;
+    bool anyDynamicHlsActive = m_view && (!rangesMouseIn->empty() || !rangesCaretIn->empty());
 
-        // sort all ranges, we want that the most specific ranges win during rendering, multiple equal ranges are kind of random, still better than old smart
-        // rangs behavior ;)
-        std::sort(rangesWithAttributes.begin(), rangesWithAttributes.end(), rangeLessThanForRenderer);
+    // sort all ranges, we want that the most specific ranges win during rendering, multiple equal ranges are kind of random, still better than old smart
+    // rangs behavior ;)
+    std::sort(rangesWithAttributes.begin(), rangesWithAttributes.end(), rangeLessThanForRenderer);
 
-        // loop over all ranges
-        for (int i = 0; i < rangesWithAttributes.size(); ++i) {
-            // real range
-            Kate::TextRange *kateRange = rangesWithAttributes[i];
+    renderRanges.reserve(rangesWithAttributes.size());
+    // loop over all ranges
+    for (int i = 0; i < rangesWithAttributes.size(); ++i) {
+        // real range
+        Kate::TextRange *kateRange = rangesWithAttributes[i];
 
-            // calculate attribute, default: normal attribute
-            KTextEditor::Attribute::Ptr attribute = kateRange->attribute();
-            if (anyDynamicHlsActive) {
-                // check mouse in
-                if (KTextEditor::Attribute::Ptr attributeMouseIn = attribute->dynamicAttribute(KTextEditor::Attribute::ActivateMouseIn)) {
-                    if (rangesMouseIn->contains(kateRange)) {
-                        attribute = attributeMouseIn;
-                    }
-                }
-
-                // check caret in
-                if (KTextEditor::Attribute::Ptr attributeCaretIn = attribute->dynamicAttribute(KTextEditor::Attribute::ActivateCaretIn)) {
-                    if (rangesCaretIn->contains(kateRange)) {
-                        attribute = attributeCaretIn;
-                    }
+        // calculate attribute, default: normal attribute
+        KTextEditor::Attribute::Ptr attribute = kateRange->attribute();
+        if (anyDynamicHlsActive) {
+            // check mouse in
+            if (KTextEditor::Attribute::Ptr attributeMouseIn = attribute->dynamicAttribute(KTextEditor::Attribute::ActivateMouseIn)) {
+                if (rangesMouseIn->contains(kateRange)) {
+                    attribute = attributeMouseIn;
                 }
             }
 
-            // span range
-            renderRanges.pushNewRange().addRange(*kateRange, attribute);
+            // check caret in
+            if (KTextEditor::Attribute::Ptr attributeCaretIn = attribute->dynamicAttribute(KTextEditor::Attribute::ActivateCaretIn)) {
+                if (rangesCaretIn->contains(kateRange)) {
+                    attribute = attributeCaretIn;
+                }
+            }
         }
+
+        // span range
+        renderRanges.pushNewRange().addRange(*kateRange, std::move(attribute));
     }
 
     // Add selection highlighting if we're creating the selection decorations
-    if ((m_view && selectionsOnly && showSelections() && m_view->selection()) || (completionHighlight && completionSelected)
-        || (m_view && m_view->blockSelection())) {
+    if ((m_view && selectionsOnly && showSelections() && m_view->selection()) || (m_view && m_view->blockSelection())) {
         auto &currentRange = renderRanges.pushNewRange();
 
         // Set up the selection background attribute TODO: move this elsewhere, eg. into the config?
@@ -435,9 +524,7 @@ KateRenderer::decorationsForLine(const Kate::TextLine &textLine, int line, bool
         backgroundAttribute->setForeground(attribute(KTextEditor::dsNormal)->selectedForeground().color());
 
         // Create a range for the current selection
-        if (completionHighlight && completionSelected) {
-            currentRange.addRange(KTextEditor::Range(line, 0, line + 1, 0), backgroundAttribute);
-        } else if (m_view->blockSelection() && m_view->selectionRange().overlapsLine(line)) {
+        if (m_view->blockSelection() && m_view->selectionRange().overlapsLine(line)) {
             currentRange.addRange(m_doc->rangeOnLine(m_view->selectionRange(), line), backgroundAttribute);
         } else {
             currentRange.addRange(m_view->selectionRange(), backgroundAttribute);
@@ -450,7 +537,8 @@ KateRenderer::decorationsForLine(const Kate::TextLine &textLine, int line, bool
     }
 
     // Calculate the range which we need to iterate in order to get the highlighting for just this line
-    KTextEditor::Cursor currentPosition, endPosition;
+    KTextEditor::Cursor currentPosition;
+    KTextEditor::Cursor endPosition;
     if (m_view && selectionsOnly) {
         if (m_view->blockSelection()) {
             KTextEditor::Range subRange = m_doc->rangeOnLine(m_view->selectionRange(), line);
@@ -508,6 +596,13 @@ KateRenderer::decorationsForLine(const Kate::TextLine &textLine, int line, bool
         currentPosition = nextPosition;
     }
 
+    // ensure bold & italic fonts work, even if the main font is e.g. light or something like that
+    for (auto &formatRange : newHighlight) {
+        if (formatRange.format.fontWeight() == QFont::Bold || formatRange.format.fontItalic()) {
+            formatRange.format.setFontStyleName(QString());
+        }
+    }
+
     return newHighlight;
 }
 
@@ -590,21 +685,32 @@ void KateRenderer::paintTextLine(QPainter &paint, KateLineLayoutPtr range, int x
             }
         }
 
+        // Check if we are at a bracket and color the indentation
+        // line differently
+        const bool indentLinesEnabled = showIndentLines();
+        if (cursor && indentLinesEnabled) {
+            auto cur = *cursor;
+            cur.setColumn(cur.column() - 1);
+            if (!m_currentBracketRange.boundaryAtCursor(*cursor) && m_currentBracketRange.end() != cur && m_currentBracketRange.start() != cur) {
+                m_currentBracketRange = cursorAtBracket(view(), range, *cursor, m_currentOpenBracketX, m_currentCloseBracketX);
+            }
+        }
+
         // Loop each individual line for additional text decoration etc.
         for (int i = 0; i < range->viewLineCount(); ++i) {
             KateTextLayout line = range->viewLine(i);
 
             // Draw indent lines
-            if (!m_printerFriendly && (showIndentLines() && i == 0)) {
+            if (!m_printerFriendly && (indentLinesEnabled && i == 0)) {
                 const qreal w = spaceWidth();
                 const int lastIndentColumn = range->textLine()->indentDepth(m_tabWidth);
                 for (int x = m_indentWidth; x < lastIndentColumn; x += m_indentWidth) {
-                    paintIndentMarker(paint, x * w + 1 - xStart);
+                    paintIndentMarker(paint, x * w + 1 - xStart, range->line());
                 }
             }
 
             // draw an open box to mark non-breaking spaces
-            const QString &text = range->textLine()->string();
+            const QString &text = range->textLine()->text();
             int y = lineHeight() * i + fm.ascent() - fm.strikeOutPos();
             int nbSpaceIndex = text.indexOf(nbSpaceChar, line.lineLayout().xToCursor(xStart));
 
@@ -638,10 +744,11 @@ void KateRenderer::paintTextLine(QPainter &paint, KateLineLayoutPtr range, int x
                 if (spaceIndex >= trailingPos) {
                     for (; spaceIndex >= line.startCol(); --spaceIndex) {
                         if (!text.at(spaceIndex).isSpace()) {
-                            if (showSpaces() == KateDocumentConfig::Trailing)
+                            if (showSpaces() == KateDocumentConfig::Trailing) {
                                 break;
-                            else
+                            } else {
                                 continue;
+                            }
                         }
 
                         if (text.at(spaceIndex) != QLatin1Char('\t') || !showTabs()) {
@@ -689,7 +796,8 @@ void KateRenderer::paintTextLine(QPainter &paint, KateLineLayoutPtr range, int x
 
         // Draw caret
         if (drawCaret() && cursor && range->includesCursor(*cursor)) {
-            int caretWidth, lineWidth = 2;
+            int caretWidth;
+            int lineWidth = 2;
             QColor color;
             QTextLine line = range->layout()->lineForTextPosition(qMin(cursor->column(), range->length()));
 
@@ -918,9 +1026,9 @@ void KateRenderer::layoutLine(KateLineLayoutPtr lineLayout, int maxwidth, bool c
 
     QTextLayout *l = lineLayout->layout();
     if (!l) {
-        l = new QTextLayout(textLine->string(), m_font);
+        l = new QTextLayout(textLine->text(), m_font);
     } else {
-        l->setText(textLine->string());
+        l->setText(textLine->text());
         l->setFont(m_font);
     }
 
@@ -932,7 +1040,7 @@ void KateRenderer::layoutLine(KateLineLayoutPtr lineLayout, int maxwidth, bool c
     QTextOption opt;
     opt.setFlags(QTextOption::IncludeTrailingSpaces);
     opt.setTabStopDistance(m_tabWidth * m_fontMetrics.horizontalAdvance(spaceChar));
-    if (m_view->config()->dynWrapAnywhere()) {
+    if (m_view && m_view->config()->dynWrapAnywhere()) {
         opt.setWrapMode(QTextOption::WrapAnywhere);
     } else {
         opt.setWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
@@ -960,9 +1068,10 @@ void KateRenderer::layoutLine(KateLineLayoutPtr lineLayout, int maxwidth, bool c
 
     int firstLineOffset = 0;
 
-    if (!isPrinterFriendly()) {
+    if (!isPrinterFriendly() && m_view) {
         const auto inlineNotes = m_view->inlineNotes(lineLayout->line());
-        for (const KTextEditor::InlineNote &inlineNote : inlineNotes) {
+        for (const KateInlineNoteData &noteData : inlineNotes) {
+            const KTextEditor::InlineNote inlineNote(noteData);
             const int column = inlineNote.position().column();
             int width = inlineNote.width();
 
@@ -1017,7 +1126,7 @@ void KateRenderer::layoutLine(KateLineLayoutPtr lineLayout, int maxwidth, bool c
             }
 
             // check for too deep shift value and limit if necessary
-            if (shiftX > ((double)maxwidth / 100 * m_view->config()->dynWordWrapAlignIndent())) {
+            if (m_view && shiftX > ((double)maxwidth / 100 * m_view->config()->dynWordWrapAlignIndent())) {
                 shiftX = 0;
             }
 
@@ -1042,7 +1151,7 @@ void KateRenderer::layoutLine(KateLineLayoutPtr lineLayout, int maxwidth, bool c
 // 5) isStringRightToLeft() kicks ass
 bool KateRenderer::isLineRightToLeft(KateLineLayoutPtr lineLayout) const
 {
-    QString s = lineLayout->textLine()->string();
+    QString s = lineLayout->textLine()->text();
     int i = 0;
 
     // borrowed from QString::updateProperties()
@@ -1083,7 +1192,7 @@ int KateRenderer::cursorToX(const KateTextLayout &range, int col, bool returnPas
     return cursorToX(range, KTextEditor::Cursor(range.line(), col), returnPastLine);
 }
 
-int KateRenderer::cursorToX(const KateTextLayout &range, const KTextEditor::Cursor &pos, bool returnPastLine) const
+int KateRenderer::cursorToX(const KateTextLayout &range, const KTextEditor::Cursor pos, bool returnPastLine) const
 {
     Q_ASSERT(range.isValid());
 
