@@ -290,11 +290,7 @@ public:
      *
      * \param selectionsOnly return decorations for selections and/or dynamic highlighting.
      */
-    QVector<QTextLayout::FormatRange> decorationsForLine(const Kate::TextLine &textLine,
-                                                         int line,
-                                                         bool selectionsOnly = false,
-                                                         bool completionHighlight = false,
-                                                         bool completionSelected = false) const;
+    QVector<QTextLayout::FormatRange> decorationsForLine(const Kate::TextLine &textLine, int line, bool selectionsOnly = false) const;
 
     // Width calculators
     qreal spaceWidth() const;
@@ -423,7 +419,7 @@ private:
     void paintNonPrintableSpaces(QPainter &paint, qreal x, qreal y, const QChar &chr);
 
     /** Paint a SciTE-like indent marker. */
-    void paintIndentMarker(QPainter &paint, uint x);
+    void paintIndentMarker(QPainter &paint, uint x, int line);
 
     void assignSelectionBrushesFromAttribute(QTextLayout::FormatRange &target, const KTextEditor::Attribute &attribute) const;
 
@@ -440,6 +436,13 @@ private:
     int m_fontHeight;
     float m_fontAscent;
 
+    // if we are at bracket, this will have the X for the opener
+    int m_currentOpenBracketX = -1;
+    // if we are at bracket, this will have the X for the closer
+    int m_currentCloseBracketX = -1;
+    // The bracket range, if we are at a bracket
+    KTextEditor::Range m_currentBracketRange = KTextEditor::Range::invalid();
+
     // some internal flags
     KateRenderer::caretStyles m_caretStyle;
     bool m_drawCaret;
