@@ -43,16 +43,22 @@ public:
      * sensitivity and if the dot "." metacharacter matches any character
      * including a newline.
      *
+     * Note: Unicode support is always enabled (QRegularExpression::UseUnicodePropertiesOption).
+     * If the pattern is multi-line the QRegularExpression::MultilineOption is enabled.
+     *
      * \param pattern text to search for
      * \param inputRange Range to search in
      * \param backwards if \e true, the search will be backwards
-     * \param options QRegularExpression pattern options
+     * \param options QRegularExpression pattern options, we will internally add QRegularExpression::UseUnicodePropertiesOption
      * \return Vector of ranges, one for each capture group. The first range (index
      *         zero) spans the whole match. If no matches are found, the vector will
      *         contain one element, an invalid range (see Range::isValid()).
      * \see KTextEditor::Range, QRegularExpression
      */
-    QVector<KTextEditor::Range> search(const QString &pattern, const KTextEditor::Range &inputRange, bool backwards = false, QRegularExpression::PatternOptions options = QRegularExpression::NoPatternOption);
+    QVector<KTextEditor::Range> search(const QString &pattern,
+                                       KTextEditor::Range inputRange,
+                                       bool backwards = false,
+                                       QRegularExpression::PatternOptions options = QRegularExpression::NoPatternOption);
 
     /**
      * Returns a modified version of text where escape sequences are resolved, e.g. "\\n" to "\n".
