@@ -18,10 +18,35 @@ KateUndoManager::KateUndoManager(KTextEditor::DocumentPrivate *doc)
     : QObject(doc)
     , m_document(doc)
 {
-    connect(this, SIGNAL(undoEnd(KTextEditor::Document *)), this, SIGNAL(undoChanged()));
-    connect(this, SIGNAL(redoEnd(KTextEditor::Document *)), this, SIGNAL(undoChanged()));
+    connect(this, &KateUndoManager::undoEnd, this, &KateUndoManager::undoChanged);
+    connect(this, &KateUndoManager::redoEnd, this, &KateUndoManager::undoChanged);
 
-    connect(doc, SIGNAL(viewCreated(KTextEditor::Document *, KTextEditor::View *)), SLOT(viewCreated(KTextEditor::Document *, KTextEditor::View *)));
+    connect(doc, &KTextEditor::DocumentPrivate::viewCreated, this, &KateUndoManager::viewCreated);
+
+    // Before reload save history
+    connect(doc, &KTextEditor::DocumentPrivate::aboutToReload, this, [this] {
+        savedUndoItems = undoItems;
+        savedRedoItems = redoItems;
+        undoItems.clear();
+        redoItems.clear();
+        docChecksumBeforeReload = m_document->checksum();
+    });
+
+    // After reload restore it only if checksum of the doc is same
+    connect(doc, &KTextEditor::DocumentPrivate::loaded, this, [this](KTextEditor::Document *doc) {
+        if (doc && !doc->checksum().isEmpty() && !docChecksumBeforeReload.isEmpty() && doc->checksum() == docChecksumBeforeReload) {
+            undoItems = savedUndoItems;
+            redoItems = savedRedoItems;
+            Q_EMIT undoChanged();
+        } else {
+            // Else delete everything, we don't want to leak
+            qDeleteAll(savedUndoItems);
+            qDeleteAll(savedRedoItems);
+        }
+        docChecksumBeforeReload.clear();
+        savedUndoItems.clear();
+        savedRedoItems.clear();
+    });
 }
 
 KateUndoManager::~KateUndoManager()
@@ -42,7 +67,7 @@ KTextEditor::Document *KateUndoManager::document()
 
 void KateUndoManager::viewCreated(KTextEditor::Document *, KTextEditor::View *newView)
 {
-    connect(newView, SIGNAL(cursorPositionChanged(KTextEditor::View *, KTextEditor::Cursor)), SLOT(undoCancel()));
+    connect(newView, &KTextEditor::View::cursorPositionChanged, this, &KateUndoManager::undoCancel);
 }
 
 void KateUndoManager::editStart()
@@ -91,7 +116,7 @@ void KateUndoManager::editEnd()
     m_editCurrentUndo = nullptr;
 
     if (changedUndo) {
-        emit undoChanged();
+        Q_EMIT undoChanged();
     }
 
     Q_ASSERT(m_editCurrentUndo == nullptr); // must be 0 after calling this method
@@ -214,7 +239,7 @@ void KateUndoManager::setActive(bool enabled)
 
     m_isActive = enabled;
 
-    emit isActiveChanged(enabled);
+    Q_EMIT isActiveChanged(enabled);
 }
 
 uint KateUndoManager::undoCount() const
@@ -232,14 +257,14 @@ void KateUndoManager::undo()
     Q_ASSERT(m_editCurrentUndo == nullptr); // undo is not supported while we care about notifications (call editEnd() first)
 
     if (!undoItems.isEmpty()) {
-        emit undoStart(document());
+        Q_EMIT undoStart(document());
 
         undoItems.last()->undo(activeView());
         redoItems.append(undoItems.last());
         undoItems.removeLast();
         updateModified();
 
-        emit undoEnd(document());
+        Q_EMIT undoEnd(document());
     }
 }
 
@@ -248,14 +273,14 @@ void KateUndoManager::redo()
     Q_ASSERT(m_editCurrentUndo == nullptr); // redo is not supported while we care about notifications (call editEnd() first)
 
     if (!redoItems.isEmpty()) {
-        emit redoStart(document());
+        Q_EMIT redoStart(document());
 
         redoItems.last()->redo(activeView());
         undoItems.append(redoItems.last());
         redoItems.removeLast();
         updateModified();
 
-        emit redoEnd(document());
+        Q_EMIT redoEnd(document());
     }
 }
 
@@ -346,7 +371,7 @@ void KateUndoManager::clearUndo()
     lastUndoGroupWhenSaved = nullptr;
     docWasSavedWhenUndoWasEmpty = false;
 
-    emit undoChanged();
+    Q_EMIT undoChanged();
 }
 
 void KateUndoManager::clearRedo()
@@ -357,7 +382,7 @@ void KateUndoManager::clearRedo()
     lastRedoGroupWhenSaved = nullptr;
     docWasSavedWhenRedoWasEmpty = false;
 
-    emit undoChanged();
+    Q_EMIT undoChanged();
 }
 
 void KateUndoManager::setModified(bool modified)
@@ -379,11 +404,11 @@ void KateUndoManager::setModified(bool modified)
 void KateUndoManager::updateLineModifications()
 {
     // change LineSaved flag of all undo & redo items to LineModified
-    for (KateUndoGroup *undoGroup : qAsConst(undoItems)) {
+    for (KateUndoGroup *undoGroup : std::as_const(undoItems)) {
         undoGroup->flagSavedAsModified();
     }
 
-    for (KateUndoGroup *undoGroup : qAsConst(redoItems)) {
+    for (KateUndoGroup *undoGroup : std::as_const(redoItems)) {
         undoGroup->flagSavedAsModified();
     }
 
@@ -399,7 +424,7 @@ void KateUndoManager::updateLineModifications()
     }
 }
 
-void KateUndoManager::setUndoRedoCursorsOfLastGroup(const KTextEditor::Cursor &undoCursor, const KTextEditor::Cursor &redoCursor)
+void KateUndoManager::setUndoRedoCursorsOfLastGroup(const KTextEditor::Cursor undoCursor, const KTextEditor::Cursor redoCursor)
 {
     Q_ASSERT(m_editCurrentUndo == nullptr);
     if (!undoItems.isEmpty()) {
@@ -421,7 +446,7 @@ KTextEditor::Cursor KateUndoManager::lastRedoCursor() const
 
 void KateUndoManager::updateConfig()
 {
-    emit undoChanged();
+    Q_EMIT undoChanged();
 }
 
 void KateUndoManager::setAllowComplexMerge(bool allow)
