@@ -33,9 +33,7 @@ KateConfig::KateConfig(const KateConfig *parent)
 {
 }
 
-KateConfig::~KateConfig()
-{
-}
+KateConfig::~KateConfig() = default;
 
 void KateConfig::addConfigEntry(ConfigEntry &&entry)
 {
@@ -60,7 +58,9 @@ void KateConfig::finalizeConfigEntries()
     // we skip entries without a command name, these config entries are not exposed ATM
     for (const auto &entry : m_configEntries) {
         if (!entry.second.commandName.isEmpty()) {
-            Q_ASSERT_X(!m_configKeys->contains(entry.second.commandName), "finalizeConfigEntries", (QLatin1String("KEY NOT UNIQUE: ") + entry.second.commandName).toLocal8Bit().constData());
+            Q_ASSERT_X(!m_configKeys->contains(entry.second.commandName),
+                       "finalizeConfigEntries",
+                       (QLatin1String("KEY NOT UNIQUE: ") + entry.second.commandName).toLocal8Bit().constData());
             m_configKeys->append(entry.second.commandName);
             m_configKeyToEntry->insert(entry.second.commandName, &entry.second);
         }
@@ -279,6 +279,9 @@ void KateGlobalConfig::updateConfig()
     KConfigGroup cg(KTextEditor::EditorPrivate::config(), "KTextEditor Editor");
     writeConfig(cg);
     KTextEditor::EditorPrivate::config()->sync();
+
+    // trigger emission of KTextEditor::Editor::configChanged
+    KTextEditor::EditorPrivate::self()->triggerConfigChanged();
 }
 
 QTextCodec *KateGlobalConfig::fallbackCodec() const
@@ -329,7 +332,9 @@ KateDocumentConfig::KateDocumentConfig()
     addConfigEntry(ConfigEntry(BackspaceIndents, "Indent On Backspace", QString(), true));
     addConfigEntry(ConfigEntry(ShowSpacesMode, "Show Spaces", QString(), KateDocumentConfig::None));
     addConfigEntry(ConfigEntry(TrailingMarkerSize, "Trailing Marker Size", QString(), 1));
-    addConfigEntry(ConfigEntry(RemoveSpacesMode, "Remove Spaces", QString(), 0));
+    addConfigEntry(ConfigEntry(RemoveSpacesMode, "Remove Spaces", QString(), 1 /* on modified lines per default */, [](const QVariant &value) {
+        return inBounds(0, value, 2);
+    }));
     addConfigEntry(ConfigEntry(NewlineAtEOF, "Newline at End of File", QString(), true));
     addConfigEntry(ConfigEntry(OverwriteMode, "Overwrite Mode", QString(), false));
     addConfigEntry(ConfigEntry(Encoding, "Encoding", QString(), QStringLiteral("UTF-8"), [](const QVariant &value) {
@@ -342,6 +347,8 @@ KateDocumentConfig::KateDocumentConfig()
     addConfigEntry(ConfigEntry(SwapFileDirectory, "Swap Directory", QString(), QString()));
     addConfigEntry(ConfigEntry(SwapFileSyncInterval, "Swap Sync Interval", QString(), 15));
     addConfigEntry(ConfigEntry(LineLengthLimit, "Line Length Limit", QString(), 10000));
+    addConfigEntry(ConfigEntry(CamelCursor, "Camel Cursor", QString(), true));
+    addConfigEntry(ConfigEntry(AutoDetectIndent, "Auto Detect Indent", QString(), true));
 
     // finalize the entries, e.g. hashs them
     finalizeConfigEntries();
@@ -422,6 +429,9 @@ void KateDocumentConfig::updateConfig()
         KConfigGroup cg(KTextEditor::EditorPrivate::config(), "KTextEditor Document");
         writeConfig(cg);
         KTextEditor::EditorPrivate::config()->sync();
+
+        // trigger emission of KTextEditor::Editor::configChanged
+        KTextEditor::EditorPrivate::self()->triggerConfigChanged();
     }
 }
 
@@ -464,14 +474,19 @@ KateViewConfig::KateViewConfig()
     addConfigEntry(ConfigEntry(AutoBrackets, "Auto Brackets", QStringLiteral("auto-brackets"), false));
     addConfigEntry(ConfigEntry(AutoCenterLines, "Auto Center Lines", QStringLiteral("auto-center-lines"), 0));
     addConfigEntry(ConfigEntry(AutomaticCompletionInvocation, "Auto Completion", QString(), true));
+    addConfigEntry(ConfigEntry(AutomaticCompletionPreselectFirst, "Auto Completion Preselect First Entry", QString(), true));
     addConfigEntry(ConfigEntry(BackspaceRemoveComposedCharacters, "Backspace Remove Composed Characters", QString(), false));
     addConfigEntry(ConfigEntry(BookmarkSorting, "Bookmark Menu Sorting", QString(), 0));
-    addConfigEntry(ConfigEntry(CharsToEncloseSelection, "Chars To Enclose Selection", QStringLiteral("enclose-selection"), QString()));
-    addConfigEntry(ConfigEntry(DefaultMarkType, "Default Mark Type", QStringLiteral("default-mark-type"), KTextEditor::MarkInterface::markType01, [](const QVariant &value) {
-        return isPositive(value);
-    }));
+    addConfigEntry(ConfigEntry(CharsToEncloseSelection, "Chars To Enclose Selection", QStringLiteral("enclose-selection"), QStringLiteral("<>(){}[]'\"")));
+    addConfigEntry(ConfigEntry(DefaultMarkType,
+                               "Default Mark Type",
+                               QStringLiteral("default-mark-type"),
+                               KTextEditor::MarkInterface::markType01,
+                               [](const QVariant &value) {
+                                   return isPositive(value);
+                               }));
     addConfigEntry(ConfigEntry(DynWordWrapAlignIndent, "Dynamic Word Wrap Align Indent", QString(), 80, [](const QVariant &value) {
-        return inBounds(1, value, 100);
+        return inBounds(0, value, 100);
     }));
     addConfigEntry(ConfigEntry(DynWordWrapIndicators, "Dynamic Word Wrap Indicators", QString(), 1, [](const QVariant &value) {
         return inBounds(1, value, 3);
@@ -499,8 +514,8 @@ KateViewConfig::KateViewConfig()
     addConfigEntry(ConfigEntry(ShowFoldingPreview, "Folding Preview", QStringLiteral("folding-preview"), true));
     addConfigEntry(ConfigEntry(ShowIconBar, "Icon Bar", QStringLiteral("icon-bar"), false));
     addConfigEntry(ConfigEntry(ShowLineCount, "Show Line Count", QString(), false));
-    addConfigEntry(ConfigEntry(ShowLineModification, "Line Modification", QStringLiteral("modification-markers"), false));
-    addConfigEntry(ConfigEntry(ShowLineNumbers, "Line Numbers", QStringLiteral("line-numbers"), false));
+    addConfigEntry(ConfigEntry(ShowLineModification, "Line Modification", QStringLiteral("modification-markers"), true));
+    addConfigEntry(ConfigEntry(ShowLineNumbers, "Line Numbers", QStringLiteral("line-numbers"), true));
     addConfigEntry(ConfigEntry(ShowScrollBarMarks, "Scroll Bar Marks", QString(), false));
     addConfigEntry(ConfigEntry(ShowScrollBarMiniMap, "Scroll Bar MiniMap", QStringLiteral("scrollbar-minimap"), true));
     addConfigEntry(ConfigEntry(ShowScrollBarMiniMapAll, "Scroll Bar Mini Map All", QString(), true));
@@ -510,7 +525,7 @@ KateViewConfig::KateViewConfig()
     }));
     addConfigEntry(ConfigEntry(ShowWordCount, "Show Word Count", QString(), false));
     addConfigEntry(ConfigEntry(TextDragAndDrop, "Text Drag And Drop", QString(), true));
-    addConfigEntry(ConfigEntry(SmartCopyCut, "Smart Copy Cut", QString(), false));
+    addConfigEntry(ConfigEntry(SmartCopyCut, "Smart Copy Cut", QString(), true));
     addConfigEntry(ConfigEntry(UserSetsOfCharsToEncloseSelection, "User Sets Of Chars To Enclose Selection", QString(), QStringList()));
     addConfigEntry(ConfigEntry(ViInputModeStealKeys, "Vi Input Mode Steal Keys", QString(), false));
     addConfigEntry(ConfigEntry(ViRelativeLineNumbers, "Vi Relative Line Numbers", QString(), false));
@@ -519,6 +534,8 @@ KateViewConfig::KateViewConfig()
         return inBounds(0, value, 99);
     }));
     addConfigEntry(ConfigEntry(WordCompletionRemoveTail, "Word Completion Remove Tail", QString(), true));
+    addConfigEntry(ConfigEntry(ShowFocusFrame, "Show Focus Frame Around Editor", QString(), true));
+    addConfigEntry(ConfigEntry(ShowDocWithCompletion, "Show Documentation With Completion", QString(), true));
 
     // Never forget to finalize or the <CommandName> becomes not available
     finalizeConfigEntries();
@@ -534,9 +551,7 @@ KateViewConfig::KateViewConfig(KTextEditor::ViewPrivate *view)
 {
 }
 
-KateViewConfig::~KateViewConfig()
-{
-}
+KateViewConfig::~KateViewConfig() = default;
 
 void KateViewConfig::readConfig(const KConfigGroup &config)
 {
@@ -571,6 +586,9 @@ void KateViewConfig::updateConfig()
         KConfigGroup cg(KTextEditor::EditorPrivate::config(), "KTextEditor View");
         writeConfig(cg);
         KTextEditor::EditorPrivate::config()->sync();
+
+        // trigger emission of KTextEditor::Editor::configChanged
+        KTextEditor::EditorPrivate::self()->triggerConfigChanged();
     }
 }
 // END
@@ -653,9 +671,7 @@ KateRendererConfig::KateRendererConfig(KateRenderer *renderer)
     m_lineMarkerColorSet.fill(false);
 }
 
-KateRendererConfig::~KateRendererConfig()
-{
-}
+KateRendererConfig::~KateRendererConfig() = default;
 
 namespace
 {
@@ -674,8 +690,8 @@ void KateRendererConfig::readConfig(const KConfigGroup &config)
     // read generic entries
     readConfigEntries(config);
 
-    // read font, but drop all styles, else we have no bold/italic/... variants
-    setFontWithDroppedStyleName(config.readEntry(KEY_FONT, QFontDatabase::systemFont(QFontDatabase::FixedFont)));
+    // read font
+    setFont(config.readEntry(KEY_FONT, QFontDatabase::systemFont(QFontDatabase::FixedFont)));
 
     // setSchema will default to right theme
     setSchema(config.readEntry(KEY_COLOR_THEME, QString()));
@@ -725,6 +741,9 @@ void KateRendererConfig::updateConfig()
         KConfigGroup cg(KTextEditor::EditorPrivate::config(), "KTextEditor Renderer");
         writeConfig(cg);
         KTextEditor::EditorPrivate::config()->sync();
+
+        // trigger emission of KTextEditor::Editor::configChanged
+        KTextEditor::EditorPrivate::self()->triggerConfigChanged();
     }
 }
 
@@ -794,70 +813,71 @@ void KateRendererConfig::setSchemaInternal(const QString &schema)
 
     const auto theme = KateHlManager::self()->repository().theme(m_schema);
 
-    m_backgroundColor = theme.editorColor(KSyntaxHighlighting::Theme::BackgroundColor);
+    m_backgroundColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::BackgroundColor));
     m_backgroundColorSet = true;
 
-    m_selectionColor = theme.editorColor(KSyntaxHighlighting::Theme::TextSelection);
+    m_selectionColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::TextSelection));
     m_selectionColorSet = true;
 
-    m_highlightedLineColor = theme.editorColor(KSyntaxHighlighting::Theme::CurrentLine);
+    m_highlightedLineColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::CurrentLine));
     m_highlightedLineColorSet = true;
 
-    m_highlightedBracketColor = theme.editorColor(KSyntaxHighlighting::Theme::BracketMatching);
+    m_highlightedBracketColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::BracketMatching));
     m_highlightedBracketColorSet = true;
 
-    m_wordWrapMarkerColor = theme.editorColor(KSyntaxHighlighting::Theme::WordWrapMarker);
+    m_wordWrapMarkerColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::WordWrapMarker));
     m_wordWrapMarkerColorSet = true;
 
-    m_tabMarkerColor = theme.editorColor(KSyntaxHighlighting::Theme::TabMarker);
+    m_tabMarkerColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::TabMarker));
     m_tabMarkerColorSet = true;
 
-    m_indentationLineColor = theme.editorColor(KSyntaxHighlighting::Theme::IndentationLine);
+    m_indentationLineColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::IndentationLine));
     m_indentationLineColorSet = true;
 
-    m_iconBarColor = theme.editorColor(KSyntaxHighlighting::Theme::IconBorder);
+    m_iconBarColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::IconBorder));
     m_iconBarColorSet = true;
 
-    m_foldingColor = theme.editorColor(KSyntaxHighlighting::Theme::CodeFolding);
+    m_foldingColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::CodeFolding));
     m_foldingColorSet = true;
 
-    m_lineNumberColor = theme.editorColor(KSyntaxHighlighting::Theme::LineNumbers);
+    m_lineNumberColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::LineNumbers));
     m_lineNumberColorSet = true;
 
-    m_currentLineNumberColor = theme.editorColor(KSyntaxHighlighting::Theme::CurrentLineNumber);
+    m_currentLineNumberColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::CurrentLineNumber));
     m_currentLineNumberColorSet = true;
 
-    m_separatorColor = theme.editorColor(KSyntaxHighlighting::Theme::Separator);
+    m_separatorColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::Separator));
     m_separatorColorSet = true;
 
-    m_spellingMistakeLineColor = theme.editorColor(KSyntaxHighlighting::Theme::SpellChecking);
+    m_spellingMistakeLineColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::SpellChecking));
     m_spellingMistakeLineColorSet = true;
 
-    m_modifiedLineColor = theme.editorColor(KSyntaxHighlighting::Theme::ModifiedLines);
+    m_modifiedLineColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::ModifiedLines));
     m_modifiedLineColorSet = true;
 
-    m_savedLineColor = theme.editorColor(KSyntaxHighlighting::Theme::SavedLines);
+    m_savedLineColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::SavedLines));
     m_savedLineColorSet = true;
 
-    m_searchHighlightColor = theme.editorColor(KSyntaxHighlighting::Theme::SearchHighlight);
+    m_searchHighlightColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::SearchHighlight));
     m_searchHighlightColorSet = true;
 
-    m_replaceHighlightColor = theme.editorColor(KSyntaxHighlighting::Theme::ReplaceHighlight);
+    m_replaceHighlightColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::ReplaceHighlight));
     m_replaceHighlightColorSet = true;
 
     for (int i = 0; i <= KSyntaxHighlighting::Theme::MarkError - KSyntaxHighlighting::Theme::MarkBookmark; i++) {
-        QColor col = theme.editorColor(static_cast<KSyntaxHighlighting::Theme::EditorColorRole>(i + KSyntaxHighlighting::Theme::MarkBookmark));
+        QColor col =
+            QColor::fromRgba(theme.editorColor(static_cast<KSyntaxHighlighting::Theme::EditorColorRole>(i + KSyntaxHighlighting::Theme::MarkBookmark)));
         m_lineMarkerColorSet[i] = true;
         m_lineMarkerColor[i] = col;
     }
 
-    m_templateBackgroundColor = theme.editorColor(KSyntaxHighlighting::Theme::TemplateBackground);
+    m_templateBackgroundColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::TemplateBackground));
 
-    m_templateFocusedEditablePlaceholderColor = theme.editorColor(KSyntaxHighlighting::Theme::TemplateFocusedPlaceholder);
+    m_templateFocusedEditablePlaceholderColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::TemplateFocusedPlaceholder));
 
-    m_templateEditablePlaceholderColor = theme.editorColor(KSyntaxHighlighting::Theme::TemplatePlaceholder);
+    m_templateEditablePlaceholderColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::TemplatePlaceholder));
 
-    m_templateNotEditablePlaceholderColor = theme.editorColor(KSyntaxHighlighting::Theme::TemplateReadOnlyPlaceholder);
+    m_templateNotEditablePlaceholderColor = QColor::fromRgba(theme.editorColor(KSyntaxHighlighting::Theme::TemplateReadOnlyPlaceholder));
 
     m_templateColorsSet = true;
 }
@@ -878,16 +898,9 @@ void KateRendererConfig::setFont(const QFont &font)
     }
 
     configStart();
-    setFontWithDroppedStyleName(font);
-    configEnd();
-}
-
-void KateRendererConfig::setFontWithDroppedStyleName(const QFont &font)
-{
-    // Drop styleName, otherwise stuff like bold/italic/... won't work as style!
     m_font = font;
-    m_font.setStyleName(QString());
     m_fontSet = true;
+    configEnd();
 }
 
 bool KateRendererConfig::wordWrapMarker() const
