@@ -1,20 +1,7 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2003 Christoph Cullmann <cullmann@kde.org>
+/*
+    SPDX-FileCopyrightText: 2003 Christoph Cullmann <cullmann@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KATE_CONFIG_H
@@ -23,7 +10,8 @@
 #include <ktexteditor_export.h>
 
 #include <ktexteditor/markinterface.h>
-#include "ktexteditor/view.h"
+#include <ktexteditor/view.h>
+
 #include <KEncodingProber>
 
 #include <functional>
@@ -34,15 +22,21 @@
 #include <QColor>
 #include <QObject>
 #include <QVector>
-#include <QFontMetricsF>
 
 class KConfigGroup;
-namespace KTextEditor { class ViewPrivate; }
-namespace KTextEditor { class DocumentPrivate; }
+namespace KTextEditor
+{
+class ViewPrivate;
+}
+namespace KTextEditor
+{
+class DocumentPrivate;
+}
 class KateRenderer;
 
-namespace KTextEditor {
-    class EditorPrivate;
+namespace KTextEditor
+{
+class EditorPrivate;
 }
 
 class KConfig;
@@ -88,6 +82,16 @@ public:
         return m_parent ? m_parent->configKeys() : *m_configKeys.get();
     }
 
+    /**
+     * Is given key set in this config object?
+     * @param key config key, aka enum from KateConfig* classes
+     * @return is the wanted key set?
+     */
+    bool isSet(const int key) const
+    {
+        return m_configEntries.find(key) != m_configEntries.end();
+    }
+
     /**
      * Get a config value.
      * @param key config key, aka enum from KateConfig* classes
@@ -136,7 +140,8 @@ protected:
     /**
      * One config entry.
      */
-    class ConfigEntry {
+    class ConfigEntry
+    {
     public:
         /**
          * Construct one config entry.
@@ -165,13 +170,13 @@ protected:
          * KConfig entry key for this config entry, shall be unique in its group
          * e.g. "Tab Width"
          */
-         const char * const configKey;
+        const char *const configKey;
 
-         /**
-          * Command name as used in e.g. ConfigInterface or modeline/command line
-          * e.g. tab-width
-          */
-         const QString commandName;
+        /**
+         * Command name as used in e.g. ConfigInterface or modeline/command line
+         * e.g. tab-width
+         */
+        const QString commandName;
 
         /**
          * Default value if nothing special was configured
@@ -226,7 +231,7 @@ private:
      * Get full map of config entries, aka the m_configEntries of the top config object
      * @return full map with all config entries
      */
-    const std::map<int, ConfigEntry> &fullConfigEntries () const
+    const std::map<int, ConfigEntry> &fullConfigEntries() const
     {
         return m_parent ? m_parent->fullConfigEntries() : m_configEntries;
     }
@@ -234,7 +239,7 @@ private:
      * Get hash of config entries, aka the m_configKeyToEntry of the top config object
      * @return full hash with all config entries
      */
-    const QHash<QString, const ConfigEntry *> &fullConfigKeyToEntry () const
+    const QHash<QString, const ConfigEntry *> &fullConfigKeyToEntry() const
     {
         return m_parent ? m_parent->fullConfigKeyToEntry() : *m_configKeyToEntry.get();
     }
@@ -243,7 +248,7 @@ private:
     /**
      * parent config object, if any
      */
-    const KateConfig * const m_parent = nullptr;
+    const KateConfig *const m_parent = nullptr;
 
     /**
      * recursion depth
@@ -532,7 +537,17 @@ public:
         /**
          * Line length limit
          */
-        LineLengthLimit
+        LineLengthLimit,
+
+        /**
+         * Camel Cursor Movement?
+         */
+        CamelCursor,
+
+        /**
+         * Automatically detect file indentation
+         */
+        AutoDetectIndent,
     };
 
 public:
@@ -653,14 +668,10 @@ public:
     enum TabHandling {
         tabInsertsTab = 0,
         tabIndents = 1,
-        tabSmart = 2      //!< indents in leading space, otherwise inserts tab
+        tabSmart = 2 //!< indents in leading space, otherwise inserts tab
     };
 
-    enum WhitespaceRendering {
-        None,
-        Trailing,
-        All
-    };
+    enum WhitespaceRendering { None, Trailing, All };
 
     int tabHandling() const
     {
@@ -825,11 +836,7 @@ public:
         return setValue(Encoding, encoding);
     }
 
-    enum Eol {
-        eolUnix = 0,
-        eolDos = 1,
-        eolMac = 2
-    };
+    enum Eol { eolUnix = 0, eolDos = 1, eolMac = 2 };
 
     int eol() const
     {
@@ -878,11 +885,7 @@ public:
         setValue(SwapFileDirectory, directory);
     }
 
-    enum SwapFileMode {
-        DisableSwapFile = 0,
-        EnableSwapFile,
-        SwapFilePresetDirectory
-    };
+    enum SwapFileMode { DisableSwapFile = 0, EnableSwapFile, SwapFilePresetDirectory };
 
     SwapFileMode swapFileMode() const
     {
@@ -914,6 +917,26 @@ public:
         setValue(LineLengthLimit, limit);
     }
 
+    void setCamelCursor(bool on)
+    {
+        setValue(CamelCursor, on);
+    }
+
+    bool camelCursor() const
+    {
+        return value(CamelCursor).toBool();
+    }
+
+    void setAutoDetectIndent(bool on)
+    {
+        setValue(AutoDetectIndent, on);
+    }
+
+    bool autoDetectIndent() const
+    {
+        return value(AutoDetectIndent).toBool();
+    }
+
 private:
     static KateDocumentConfig *s_global;
     KTextEditor::DocumentPrivate *m_doc = nullptr;
@@ -954,12 +977,14 @@ public:
         AutoBrackets,
         AutoCenterLines,
         AutomaticCompletionInvocation,
+        AutomaticCompletionPreselectFirst,
         BackspaceRemoveComposedCharacters,
         BookmarkSorting,
         CharsToEncloseSelection,
         DefaultMarkType,
         DynWordWrapAlignIndent,
         DynWordWrapIndicators,
+        DynWrapAnywhere,
         DynWrapAtStaticMarker,
         DynamicWordWrap,
         FoldFirstLine,
@@ -971,6 +996,7 @@ public:
         ScrollBarMiniMapWidth,
         ScrollPastEnd,
         SearchFlags,
+        ShowBracketMatchPreview,
         ShowFoldingBar,
         ShowFoldingPreview,
         ShowIconBar,
@@ -991,6 +1017,8 @@ public:
         WordCompletion,
         WordCompletionMinimalWordLength,
         WordCompletionRemoveTail,
+        ShowFocusFrame,
+        ShowDocWithCompletion,
     };
 
 public:
@@ -1016,6 +1044,10 @@ public:
     {
         setValue(DynamicWordWrap, on);
     }
+    bool dynWrapAnywhere() const
+    {
+        return value(DynWrapAnywhere).toBool();
+    }
 
     bool dynWrapAtStaticMarker() const
     {
@@ -1063,17 +1095,23 @@ public:
     }
 
     /* Whether to show scrollbars */
-    enum ScrollbarMode {
-        AlwaysOn = 0,
-        ShowWhenNeeded,
-        AlwaysOff
-    };
+    enum ScrollbarMode { AlwaysOn = 0, ShowWhenNeeded, AlwaysOff };
 
     int showScrollbars() const
     {
         return value(ShowScrollbars).toInt();
     }
 
+    bool showFocusFrame() const
+    {
+        return value(ShowFocusFrame).toBool();
+    }
+
+    bool showDocWithCompletion() const
+    {
+        return value(ShowDocWithCompletion).toBool();
+    }
+
     bool iconBar() const
     {
         return value(ShowIconBar).toBool();
@@ -1164,27 +1202,26 @@ public:
     }
 
     // Do we still need the enum and related functions below?
-    enum TextToSearch {
-        Nowhere = 0,
-        SelectionOnly = 1,
-        SelectionWord = 2,
-        WordOnly = 3,
-        WordSelection = 4
-    };
+    enum TextToSearch { Nowhere = 0, SelectionOnly = 1, SelectionWord = 2, WordOnly = 3, WordSelection = 4 };
 
     bool automaticCompletionInvocation() const
     {
         return value(AutomaticCompletionInvocation).toBool();
     }
 
+    bool automaticCompletionPreselectFirst() const
+    {
+        return value(AutomaticCompletionPreselectFirst).toBool();
+    }
+
     bool wordCompletion() const
     {
         return value(WordCompletion).toBool();
     }
 
-    bool keywordCompletion () const
+    bool keywordCompletion() const
     {
-         return value(KeywordCompletion).toBool();
+        return value(KeywordCompletion).toBool();
     }
 
     int wordCompletionMinimalWordLength() const
@@ -1236,6 +1273,11 @@ public:
         return value(ShowLineCount).toBool();
     }
 
+    void setShowLineCount(bool on)
+    {
+        setValue(ShowLineCount, on);
+    }
+
     bool autoBrackets() const
     {
         return value(AutoBrackets).toBool();
@@ -1287,6 +1329,17 @@ public:
         return s_global;
     }
 
+    /**
+     * All known config keys
+     * Keep them sorted alphabetic for our convenience
+     */
+    enum ConfigEntryTypes {
+        /**
+         * auto-select the color theme based on application palette
+         */
+        AutoColorThemeSelection
+    };
+
 public:
     /**
      * Read config from object
@@ -1303,7 +1356,7 @@ protected:
 
 public:
     const QString &schema() const;
-    void setSchema(const QString &schema);
+    void setSchema(QString schema);
 
     /**
      * Reload the schema from the schema manager.
@@ -1312,8 +1365,13 @@ public:
      */
     void reloadSchema();
 
-    const QFont &font() const;
-    const QFontMetricsF &fontMetrics() const;
+    /**
+     * Base font to use for the views and co.
+     * Will be adjusted there to avoid rendering artifacts for HiDPI stuff.
+     * @return base font to use
+     */
+    const QFont &baseFont() const;
+
     void setFont(const QFont &font);
 
     bool wordWrapMarker() const;
@@ -1329,7 +1387,6 @@ public:
     void setHighlightedLineColor(const QColor &col);
 
     const QColor &lineMarkerColor(KTextEditor::MarkInterface::MarkTypes type = KTextEditor::MarkInterface::markType01) const; // markType01 == Bookmark
-    void setLineMarkerColor(const QColor &col, KTextEditor::MarkInterface::MarkTypes type = KTextEditor::MarkInterface::markType01);
 
     const QColor &highlightedBracketColor() const;
     void setHighlightedBracketColor(const QColor &col);
@@ -1394,15 +1451,8 @@ private:
      */
     void setSchemaInternal(const QString &schema);
 
-    /**
-     * Set the font but drop style name before that.
-     * Otherwise e.g. styles like bold/italic/... will not work
-     */
-    void setFontWithDroppedStyleName(const QFont &font);
-
     QString m_schema;
     QFont m_font;
-    QFontMetricsF m_fontMetrics;
     QColor m_backgroundColor;
     QColor m_selectionColor;
     QColor m_highlightedLineColor;
@@ -1464,4 +1514,3 @@ private:
 };
 
 #endif
-
