@@ -44,10 +44,6 @@
 #include <QStringListModel>
 #include <QTimer>
 
-#if LIBGIT2_FOUND
-#include <git2.h>
-#endif
-
 // BEGIN unit test mode
 static bool kateUnitTestMode = false;
 
@@ -69,7 +65,7 @@ KTextEditor::EditorPrivate::EditorPrivate(QPointer<KTextEditor::EditorPrivate> &
                   QStringLiteral(KTEXTEDITOR_VERSION_STRING),
                   i18n("Embeddable editor component"),
                   KAboutLicense::LGPL_V2,
-                  i18n("(c) 2000-2021 The Kate Authors"),
+                  i18n("(c) 2000-2022 The Kate Authors"),
                   QString(),
                   QStringLiteral("https://kate-editor.org"))
     , m_dummyApplication(nullptr)
@@ -81,11 +77,6 @@ KTextEditor::EditorPrivate::EditorPrivate(QPointer<KTextEditor::EditorPrivate> &
     // remember this
     staticInstance = this;
 
-    // init libgit2, we require at least 0.22 which has this function!
-#if LIBGIT2_FOUND
-    git_libgit2_init();
-#endif
-
     // register some datatypes
     qRegisterMetaType<KTextEditor::Cursor>("KTextEditor::Cursor");
     qRegisterMetaType<KTextEditor::Document *>("KTextEditor::Document*");
@@ -247,11 +238,6 @@ KTextEditor::EditorPrivate::~EditorPrivate()
     // delete the commands before we delete the cmd manager
     qDeleteAll(m_cmds);
     delete m_cmdManager;
-
-    // shutdown libgit2, we require at least 0.22 which has this function!
-#if LIBGIT2_FOUND
-    git_libgit2_shutdown();
-#endif
 }
 
 KTextEditor::Document *KTextEditor::EditorPrivate::createDocument(QObject *parent)
