@@ -55,6 +55,7 @@ namespace Kate
 class TextRange;
 }
 
+class QTextCodec;
 class QTimer;
 class QVBoxLayout;
 
@@ -386,6 +387,7 @@ private:
 private Q_SLOTS:
     void highlightFolding();
     void handleDestroyedAnnotationItemDelegate();
+    void delayedUpdateOfSizeWithRepaint();
 
 private:
     QString m_hoveredAnnotationGroupIdentifier;
@@ -557,13 +559,8 @@ public:
     void removePermanentBarWidget(KateViewBarWidget *barWidget);
 
     /**
-     * @return if viewbar has permanent widget @p barWidget
-     */
-    bool hasPermanentWidget(KateViewBarWidget *barWidget) const;
-
-    /**
-     * @return true if the KateViewBar is hidden or displays a permanentBarWidget */
-    bool hiddenOrPermanent() const;
+     * @return true if the a KateViewBar is visible*/
+    bool barWidgetVisible() const;
 
 public Q_SLOTS:
     /**
