@@ -1,48 +1,33 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2013-2016 Simon St James <kdedevel@etotheipiplusone.com>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2013-2016 Simon St James <kdedevel@etotheipiplusone.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include <vimode/emulatedcommandbar/emulatedcommandbar.h>
 
+#include "../commandrangeexpressionparser.h"
+#include "../globalstate.h"
+#include "commandmode.h"
+#include "interactivesedreplacemode.h"
 #include "katedocument.h"
 #include "kateglobal.h"
-#include "../commandrangeexpressionparser.h"
 #include "kateview.h"
-#include "../globalstate.h"
-#include <vimode/keyparser.h>
-#include <vimode/inputmodemanager.h>
-#include <inputmode/kateviinputmode.h>
-#include <vimode/modes/normalvimode.h>
 #include "matchhighlighter.h"
-#include "interactivesedreplacemode.h"
 #include "searchmode.h"
-#include "commandmode.h"
+#include <inputmode/kateviinputmode.h>
+#include <vimode/inputmodemanager.h>
+#include <vimode/keyparser.h>
+#include <vimode/modes/normalvimode.h>
 
 #include "../history.h"
 
 #include "../registers.h"
-#include "../searcher.h"
 
+#include <QApplication>
+#include <QLabel>
 #include <QLineEdit>
 #include <QVBoxLayout>
-#include <QLabel>
-#include <QApplication>
 
 #include <algorithm>
 
@@ -70,15 +55,14 @@ QString escapedForSearchingAsLiteral(const QString &originalQtRegex)
 }
 }
 
-EmulatedCommandBar::EmulatedCommandBar(KateViInputMode* viInputMode, InputModeManager *viInputModeManager, QWidget *parent)
-    : KateViewBarWidget(false, parent),
-      m_viInputMode(viInputMode),
-      m_viInputModeManager(viInputModeManager),
-      m_view(viInputModeManager->view())
+EmulatedCommandBar::EmulatedCommandBar(KateViInputMode *viInputMode, InputModeManager *viInputModeManager, QWidget *parent)
+    : KateViewBarWidget(false, parent)
+    , m_viInputMode(viInputMode)
+    , m_viInputModeManager(viInputModeManager)
+    , m_view(viInputModeManager->view())
 {
-    QHBoxLayout *layout = new QHBoxLayout();
-    layout->setMargin(0);
-    centralWidget()->setLayout(layout);
+    QHBoxLayout *layout = new QHBoxLayout(centralWidget());
+    layout->setContentsMargins(0, 0, 0, 0);
 
     createAndAddBarTypeIndicator(layout);
     createAndAddEditWidget(layout);
@@ -93,15 +77,14 @@ EmulatedCommandBar::EmulatedCommandBar(KateViInputMode* viInputMode, InputModeMa
     m_interactiveSedReplaceMode.reset(new InteractiveSedReplaceMode(this, m_matchHighligher.data(), m_viInputModeManager, m_view));
     layout->addWidget(m_interactiveSedReplaceMode->label());
     m_searchMode.reset(new SearchMode(this, m_matchHighligher.data(), m_viInputModeManager, m_view, m_edit));
-    m_commandMode.reset(new CommandMode(this, m_matchHighligher.data(), m_viInputModeManager, m_view, m_edit, m_interactiveSedReplaceMode.data(), m_completer.data()));
+    m_commandMode.reset(
+        new CommandMode(this, m_matchHighligher.data(), m_viInputModeManager, m_view, m_edit, m_interactiveSedReplaceMode.data(), m_completer.data()));
 
     m_edit->installEventFilter(this);
-    connect(m_edit, SIGNAL(textChanged(QString)), this, SLOT(editTextChanged(QString)));
+    connect(m_edit, &QLineEdit::textChanged, this, &EmulatedCommandBar::editTextChanged);
 }
 
-EmulatedCommandBar::~EmulatedCommandBar()
-{
-}
+EmulatedCommandBar::~EmulatedCommandBar() = default;
 
 void EmulatedCommandBar::init(EmulatedCommandBar::Mode mode, const QString &initialText)
 {
@@ -111,13 +94,10 @@ void EmulatedCommandBar::init(EmulatedCommandBar::Mode mode, const QString &init
 
     showBarTypeIndicator(mode);
 
-    if (mode == KateVi::EmulatedCommandBar::SearchBackward || mode == SearchForward)
-    {
+    if (mode == KateVi::EmulatedCommandBar::SearchBackward || mode == SearchForward) {
         switchToMode(m_searchMode.data());
         m_searchMode->init(mode == SearchBackward ? SearchMode::SearchDirection::Backward : SearchMode::SearchDirection::Forward);
-    }
-    else
-    {
+    } else {
         switchToMode(m_commandMode.data());
     }
 
@@ -151,32 +131,36 @@ void EmulatedCommandBar::closed()
     m_completer->deactivateCompletion();
     m_isActive = false;
 
-    if (m_currentMode)
-    {
+    if (m_currentMode) {
         m_currentMode->deactivate(m_wasAborted);
         m_currentMode = nullptr;
     }
 }
 
-void EmulatedCommandBar::switchToMode ( ActiveMode* newMode )
+void EmulatedCommandBar::switchToMode(ActiveMode *newMode)
 {
-    if (m_currentMode)
+    if (newMode == m_currentMode) {
+        return;
+    }
+    if (m_currentMode) {
         m_currentMode->deactivate(false);
+    }
     m_currentMode = newMode;
     m_completer->setCurrentMode(newMode);
 }
 
-bool EmulatedCommandBar::barHandledKeypress ( const QKeyEvent* keyEvent )
+bool EmulatedCommandBar::barHandledKeypress(const QKeyEvent *keyEvent)
 {
-    if ((keyEvent->modifiers() == Qt::ControlModifier && keyEvent->key() == Qt::Key_H) || keyEvent->key() == Qt::Key_Backspace) {
+    if ((keyEvent->modifiers() == CONTROL_MODIFIER && keyEvent->key() == Qt::Key_H) || keyEvent->key() == Qt::Key_Backspace) {
         if (m_edit->text().isEmpty()) {
-            emit hideMe();
+            Q_EMIT hideMe();
         }
         m_edit->backspace();
         return true;
     }
-    if (keyEvent->modifiers() != Qt::ControlModifier)
+    if (keyEvent->modifiers() != CONTROL_MODIFIER) {
         return false;
+    }
     if (keyEvent->key() == Qt::Key_B) {
         m_edit->setCursorPosition(0);
         return true;
@@ -207,7 +191,7 @@ void EmulatedCommandBar::insertRegisterContents(const QKeyEvent *keyEvent)
 
         const int oldCursorPosition = m_edit->cursorPosition();
         QString textToInsert;
-        if (keyEvent->modifiers() == Qt::ControlModifier && keyEvent->key() == Qt::Key_W) {
+        if (keyEvent->modifiers() == CONTROL_MODIFIER && keyEvent->key() == Qt::Key_W) {
             textToInsert = m_view->doc()->wordAt(m_view->cursorPosition());
         } else {
             textToInsert = m_viInputModeManager->globalState()->registers()->getContent(key);
@@ -279,23 +263,26 @@ bool EmulatedCommandBar::handleKeyPress(const QKeyEvent *keyEvent)
         return true;
     }
     const bool completerHandled = m_completer->completerHandledKeypress(keyEvent);
-    if (completerHandled)
+    if (completerHandled) {
         return true;
+    }
 
-    if (keyEvent->modifiers() == Qt::ControlModifier && (keyEvent->key() == Qt::Key_C || keyEvent->key() == Qt::Key_BracketLeft)) {
-        emit hideMe();
+    if (keyEvent->modifiers() == CONTROL_MODIFIER && (keyEvent->key() == Qt::Key_C || keyEvent->key() == Qt::Key_BracketLeft)) {
+        Q_EMIT hideMe();
         return true;
     }
 
     // Is this a built-in Emulated Command Bar keypress e.g. insert from register, ctrl-h, etc?
     const bool barHandled = barHandledKeypress(keyEvent);
-    if (barHandled)
+    if (barHandled) {
         return true;
+    }
 
     // Can the current mode handle it?
     const bool currentModeHandled = m_currentMode->handleKeyPress(keyEvent);
-    if (currentModeHandled)
+    if (currentModeHandled) {
         return true;
+    }
 
     // Couldn't handle this key event.
     // Send the keypress back to the QLineEdit.  Ideally, instead of doing this, we would simply return "false"
@@ -304,9 +291,10 @@ bool EmulatedCommandBar::handleKeyPress(const QKeyEvent *keyEvent)
     // is not dispatched from within KateViInputModeHandler::handleKeypress(...)
     // (so KateViInputModeManager::isHandlingKeypress() returns false), we lose information about whether we are
     // in Visual Mode, Visual Line Mode, etc.  See VisualViMode::updateSelection( ).
-    if (m_edit->isVisible())
-    {
-        if (m_suspendEditEventFiltering) return false;
+    if (m_edit->isVisible()) {
+        if (m_suspendEditEventFiltering) {
+            return false;
+        }
         m_suspendEditEventFiltering = true;
         QKeyEvent keyEventCopy(keyEvent->type(), keyEvent->key(), keyEvent->modifiers(), keyEvent->text(), keyEvent->isAutoRepeat(), keyEvent->count());
         qApp->notify(m_edit, &keyEventCopy);
@@ -322,7 +310,9 @@ bool EmulatedCommandBar::isSendingSyntheticSearchCompletedKeypress()
 
 void EmulatedCommandBar::startInteractiveSearchAndReplace(QSharedPointer<SedReplace::InteractiveSedReplacer> interactiveSedReplace)
 {
-    Q_ASSERT_X(interactiveSedReplace->currentMatch().isValid(), "startInteractiveSearchAndReplace", "KateCommands shouldn't initiate an interactive sed replace with no initial match");
+    Q_ASSERT_X(interactiveSedReplace->currentMatch().isValid(),
+               "startInteractiveSearchAndReplace",
+               "KateCommands shouldn't initiate an interactive sed replace with no initial match");
     switchToMode(m_interactiveSedReplaceMode.data());
     m_interactiveSedReplaceMode->activate(interactiveSedReplace);
 }
@@ -386,32 +376,31 @@ void EmulatedCommandBar::setViInputModeManager(InputModeManager *viInputModeMana
     m_interactiveSedReplaceMode->setViInputModeManager(viInputModeManager);
 }
 
-void EmulatedCommandBar::hideAllWidgetsExcept(QWidget* widgetToKeepVisible)
+void EmulatedCommandBar::hideAllWidgetsExcept(QWidget *widgetToKeepVisible)
 {
-    QList<QWidget*> widgets = centralWidget()->findChildren<QWidget*>();
-    foreach(QWidget* widget, widgets)
-    {
-        if (widget != widgetToKeepVisible)
+    const QList<QWidget *> widgets = centralWidget()->findChildren<QWidget *>();
+    for (QWidget *widget : widgets) {
+        if (widget != widgetToKeepVisible) {
             widget->hide();
+        }
     }
-
 }
 
-void EmulatedCommandBar::createAndAddBarTypeIndicator(QLayout* layout)
+void EmulatedCommandBar::createAndAddBarTypeIndicator(QLayout *layout)
 {
     m_barTypeIndicator = new QLabel(this);
     m_barTypeIndicator->setObjectName(QStringLiteral("bartypeindicator"));
     layout->addWidget(m_barTypeIndicator);
 }
 
-void EmulatedCommandBar::createAndAddEditWidget(QLayout* layout)
+void EmulatedCommandBar::createAndAddEditWidget(QLayout *layout)
 {
     m_edit = new QLineEdit(this);
     m_edit->setObjectName(QStringLiteral("commandtext"));
     layout->addWidget(m_edit);
 }
 
-void EmulatedCommandBar::createAndAddExitStatusMessageDisplay(QLayout* layout)
+void EmulatedCommandBar::createAndAddExitStatusMessageDisplay(QLayout *layout)
 {
     m_exitStatusMessageDisplay = new QLabel(this);
     m_exitStatusMessageDisplay->setObjectName(QStringLiteral("commandresponsemessage"));
@@ -423,17 +412,16 @@ void EmulatedCommandBar::createAndInitExitStatusMessageDisplayTimer()
 {
     m_exitStatusMessageDisplayHideTimer = new QTimer(this);
     m_exitStatusMessageDisplayHideTimer->setSingleShot(true);
-    connect(m_exitStatusMessageDisplayHideTimer, SIGNAL(timeout()),
-            this, SIGNAL(hideMe()));
+    connect(m_exitStatusMessageDisplayHideTimer, &QTimer::timeout, this, &EmulatedCommandBar::hideMe);
     // Make sure the timer is stopped when the user switches views. If not, focus will be given to the
     // wrong view when KateViewBar::hideCurrentBarWidget() is called as a result of m_commandResponseMessageDisplayHide
     // timing out.
-    connect(m_view, SIGNAL(focusOut(KTextEditor::View*)), m_exitStatusMessageDisplayHideTimer, SLOT(stop()));
+    connect(m_view, &KTextEditor::ViewPrivate::focusOut, m_exitStatusMessageDisplayHideTimer, &QTimer::stop);
     // We can restart the timer once the view has focus again, though.
-    connect(m_view, SIGNAL(focusIn(KTextEditor::View*)), this, SLOT(startHideExitStatusMessageTimer()));
+    connect(m_view, &KTextEditor::ViewPrivate::focusIn, this, &EmulatedCommandBar::startHideExitStatusMessageTimer);
 }
 
-void EmulatedCommandBar::createAndAddWaitingForRegisterIndicator(QLayout* layout)
+void EmulatedCommandBar::createAndAddWaitingForRegisterIndicator(QLayout *layout)
 {
     m_waitingForRegisterIndicator = new QLabel(this);
     m_waitingForRegisterIndicator->setObjectName(QStringLiteral("waitingforregisterindicator"));
