@@ -7,6 +7,8 @@
 #ifndef KATEVI_MACRORECORDER_H
 #define KATEVI_MACRORECORDER_H
 
+#include "keyevent.h"
+
 #include <QChar>
 #include <QKeyEvent>
 #include <QList>
@@ -19,7 +21,6 @@ class MacroRecorder
 {
 public:
     explicit MacroRecorder(InputModeManager *viInputModeManager);
-    ~MacroRecorder();
 
     void start(const QChar &macroRegister);
     void stop();
@@ -37,7 +38,7 @@ private:
 
     bool m_isRecording;
     QChar m_register;
-    QList<QKeyEvent> m_eventsLog;
+    QList<KeyEvent> m_eventsLog;
 
     int m_macrosBeingReplayedCount;
     QChar m_lastPlayedMacroRegister;
