@@ -9,6 +9,7 @@
 #include "katecompletiontree.h"
 #include "katecompletionwidget.h"
 #include "kateconfig.h"
+#include "katedocument.h"
 #include "kateglobal.h"
 #include "katepartdebug.h"
 #include "kateview.h"
@@ -42,12 +43,10 @@ InsertViMode::InsertViMode(InputModeManager *viInputModeManager, KTextEditor::Vi
 
     m_isExecutingCompletion = false;
 
-    connect(doc(), &KTextEditor::DocumentPrivate::textInserted, this, &InsertViMode::textInserted);
+    connect(doc(), &KTextEditor::DocumentPrivate::textInsertedRange, this, &InsertViMode::textInserted);
 }
 
-InsertViMode::~InsertViMode()
-{
-}
+InsertViMode::~InsertViMode() = default;
 
 bool InsertViMode::commandInsertFromAbove()
 {
@@ -125,7 +124,7 @@ bool InsertViMode::commandDeleteLine()
          * Remove backwards until the first non-space character. If no
          * non-space was found, remove backwards to the first column.
          */
-        static const QRegularExpression nonSpace(QStringLiteral("\\S"));
+        static const QRegularExpression nonSpace(QStringLiteral("\\S"), QRegularExpression::UseUnicodePropertiesOption);
         r.startColumn = getLine().indexOf(nonSpace);
         if (r.startColumn == -1 || r.startColumn >= c.column()) {
             r.startColumn = 0;
@@ -301,13 +300,14 @@ bool InsertViMode::commandSwitchToNormalModeForJustOneCommand()
 bool InsertViMode::handleKeypress(const QKeyEvent *e)
 {
     // backspace should work even if the shift key is down
-    if (e->modifiers() != Qt::ControlModifier && e->key() == Qt::Key_Backspace) {
+    if (e->modifiers() != CONTROL_MODIFIER && e->key() == Qt::Key_Backspace) {
         m_view->backspace();
         return true;
     }
 
     if (m_keys.isEmpty() && !m_waitingRegister) {
-        if (e->modifiers() == Qt::NoModifier) {
+        // on macOS the KeypadModifier is set for arrow keys too
+        if (e->modifiers() == Qt::NoModifier || e->modifiers() == Qt::KeypadModifier) {
             switch (e->key()) {
             case Qt::Key_Escape:
                 leaveInsertMode();
@@ -363,7 +363,7 @@ bool InsertViMode::handleKeypress(const QKeyEvent *e)
             default:
                 return false;
             }
-        } else if (e->modifiers() == Qt::ControlModifier) {
+        } else if (e->modifiers() == CONTROL_MODIFIER) {
             switch (e->key()) {
             case Qt::Key_BracketLeft:
             case Qt::Key_3:
@@ -475,7 +475,8 @@ void InsertViMode::leaveInsertMode(bool force)
 
             // make sure cursor haven't been moved
             if (m_blockRange.startLine == m_view->cursorPosition().line()) {
-                int start, len;
+                int start;
+                int len;
                 QString added;
                 KTextEditor::Cursor c;
 
