@@ -10,7 +10,9 @@
 #ifndef KATEVI_NORMAL_VI_MODE_H
 #define KATEVI_NORMAL_VI_MODE_H
 
+#include <vimode/command.h>
 #include <vimode/modes/modebase.h>
+#include <vimode/motion.h>
 #include <vimode/range.h>
 
 #include <QHash>
@@ -18,6 +20,8 @@
 #include <QStack>
 #include <QVector>
 
+#include <vector>
+
 #include <ktexteditor/range.h>
 #include <ktexteditor_export.h>
 
@@ -26,8 +30,6 @@ class KateViInputMode;
 
 namespace KateVi
 {
-class Command;
-class Motion;
 class KeyParser;
 class InputModeManager;
 
@@ -293,7 +295,7 @@ protected:
     OperationMode getOperationMode() const;
 
     void highlightYank(const Range &range, const OperationMode mode = CharWise);
-    void addHighlightYank(const KTextEditor::Range &range);
+    void addHighlightYank(KTextEditor::Range range);
 
     bool motionWillBeUsedWithCommand() const
     {
@@ -326,7 +328,7 @@ protected:
     // line for linewise.
     enum PasteLocation { AtCurrentPosition, AfterCurrentPosition };
     bool paste(NormalViMode::PasteLocation pasteLocation, bool isgPaste, bool isIndentedPaste);
-    KTextEditor::Cursor cursorPosAtEndOfPaste(const KTextEditor::Cursor &pasteLocation, const QString &pastedText) const;
+    KTextEditor::Cursor cursorPosAtEndOfPaste(const KTextEditor::Cursor pasteLocation, const QString &pastedText) const;
 
 protected:
     QString m_keys;
@@ -336,8 +338,8 @@ protected:
     int m_motionOperatorIndex;
     int m_scroll_count_limit;
 
-    QVector<Command *> m_commands;
-    QVector<Motion *> m_motions;
+    std::vector<Command> m_commands;
+    std::vector<Motion> m_motions;
     QVector<int> m_matchingCommands;
     QVector<int> m_matchingMotions;
     QStack<int> m_awaitingMotionOrTextObject;
