@@ -1,28 +1,15 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2008 Erlend Hamberg <ehamberg@gmail.com>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2008 Erlend Hamberg <ehamberg@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+#include "katedocument.h"
 
-#include <view/kateviewinternal.h>
-#include <vimode/modes/replacevimode.h>
-#include <vimode/inputmodemanager.h>
 #include <utils/kateconfig.h>
+#include <view/kateviewinternal.h>
+#include <vimode/inputmodemanager.h>
 #include <vimode/marks.h>
+#include <vimode/modes/replacevimode.h>
 
 using namespace KateVi;
 
@@ -35,11 +22,6 @@ ReplaceViMode::ReplaceViMode(InputModeManager *viInputModeManager, KTextEditor::
     m_count = 1;
 }
 
-ReplaceViMode::~ReplaceViMode()
-{
-    /* There's nothing to do here. */
-}
-
 bool ReplaceViMode::commandInsertFromLine(int offset)
 {
     KTextEditor::Cursor c(m_view->cursorPosition());
@@ -99,86 +81,87 @@ bool ReplaceViMode::commandMoveOneWordRight()
 bool ReplaceViMode::handleKeypress(const QKeyEvent *e)
 {
     // backspace should work even if the shift key is down
-    if (e->modifiers() != Qt::ControlModifier && e->key() == Qt::Key_Backspace) {
+    if (e->modifiers() != CONTROL_MODIFIER && e->key() == Qt::Key_Backspace) {
         backspace();
         return true;
     }
 
-    if (e->modifiers() == Qt::NoModifier) {
+    // on macOS the KeypadModifier is set for the arrow keys too
+    if (e->modifiers() == Qt::NoModifier || e->modifiers() == Qt::KeypadModifier) {
         switch (e->key()) {
-            case Qt::Key_Escape:
-                m_overwritten.clear();
-                leaveReplaceMode();
-                return true;
-            case Qt::Key_Left:
-                m_overwritten.clear();
-                m_view->cursorLeft();
-                return true;
-            case Qt::Key_Right:
-                m_overwritten.clear();
-                m_view->cursorRight();
-                return true;
-            case Qt::Key_Up:
-                m_overwritten.clear();
-                m_view->up();
-                return true;
-            case Qt::Key_Down:
-                m_overwritten.clear();
-                m_view->down();
-                return true;
-            case Qt::Key_Home:
-                m_overwritten.clear();
-                m_view->home();
-                return true;
-            case Qt::Key_End:
-                m_overwritten.clear();
-                m_view->end();
-                return true;
-            case Qt::Key_PageUp:
-                m_overwritten.clear();
-                m_view->pageUp();
-                return true;
-            case Qt::Key_PageDown:
-                m_overwritten.clear();
-                m_view->pageDown();
-                return true;
-            case Qt::Key_Delete:
-                m_view->keyDelete();
-                return true;
-            case Qt::Key_Insert:
-                startInsertMode();
-                return true;
-            default:
-                return false;
+        case Qt::Key_Escape:
+            m_overwritten.clear();
+            leaveReplaceMode();
+            return true;
+        case Qt::Key_Left:
+            m_overwritten.clear();
+            m_view->cursorLeft();
+            return true;
+        case Qt::Key_Right:
+            m_overwritten.clear();
+            m_view->cursorRight();
+            return true;
+        case Qt::Key_Up:
+            m_overwritten.clear();
+            m_view->up();
+            return true;
+        case Qt::Key_Down:
+            m_overwritten.clear();
+            m_view->down();
+            return true;
+        case Qt::Key_Home:
+            m_overwritten.clear();
+            m_view->home();
+            return true;
+        case Qt::Key_End:
+            m_overwritten.clear();
+            m_view->end();
+            return true;
+        case Qt::Key_PageUp:
+            m_overwritten.clear();
+            m_view->pageUp();
+            return true;
+        case Qt::Key_PageDown:
+            m_overwritten.clear();
+            m_view->pageDown();
+            return true;
+        case Qt::Key_Delete:
+            m_view->keyDelete();
+            return true;
+        case Qt::Key_Insert:
+            startInsertMode();
+            return true;
+        default:
+            return false;
         }
-    } else if (e->modifiers() == Qt::ControlModifier) {
+    } else if (e->modifiers() == CONTROL_MODIFIER) {
         switch (e->key()) {
-            case Qt::Key_BracketLeft:
-            case Qt::Key_C:
-                startNormalMode();
-                return true;
-            case Qt::Key_E:
-                commandInsertFromLine(1);
-                return true;
-            case Qt::Key_Y:
-                commandInsertFromLine(-1);
-                return true;
-            case Qt::Key_W:
-                commandBackWord();
-                return true;
-            case Qt::Key_U:
-                commandBackLine();
-                return true;
-            case Qt::Key_Left:
-                m_overwritten.clear();
-                commandMoveOneWordLeft();
-                return true;
-            case Qt::Key_Right:
-                m_overwritten.clear();
-                commandMoveOneWordRight();
-                return true;
-            default:
-                return false;
+        case Qt::Key_BracketLeft:
+        case Qt::Key_C:
+            startNormalMode();
+            return true;
+        case Qt::Key_E:
+            commandInsertFromLine(1);
+            return true;
+        case Qt::Key_Y:
+            commandInsertFromLine(-1);
+            return true;
+        case Qt::Key_W:
+            commandBackWord();
+            return true;
+        case Qt::Key_U:
+            commandBackLine();
+            return true;
+        case Qt::Key_Left:
+            m_overwritten.clear();
+            commandMoveOneWordLeft();
+            return true;
+        case Qt::Key_Right:
+            m_overwritten.clear();
+            commandMoveOneWordRight();
+            return true;
+        default:
+            return false;
         }
     }
 
