@@ -8,6 +8,7 @@
 #include "globalstate.h"
 #include "history.h"
 #include "katedocument.h"
+#include "katerenderer.h"
 #include "kateview.h"
 #include "ktexteditor/range.h"
 #include <vimode/inputmodemanager.h>
@@ -18,7 +19,20 @@ using namespace KateVi;
 Searcher::Searcher(InputModeManager *manager)
     : m_viInputModeManager(manager)
     , m_view(manager->view())
+    , m_lastHlSearchRange(KTextEditor::Range::invalid())
+    , highlightMatchAttribute(new KTextEditor::Attribute())
 {
+    updateHighlightColors();
+
+    if (m_hlMode == HighlightMode::Enable) {
+        connectDisplayRangeChanged();
+    }
+}
+
+Searcher::~Searcher()
+{
+    disconnectDisplayRangeChanged();
+    clearHighlights();
 }
 
 const QString Searcher::getLastSearchPattern() const
@@ -28,7 +42,8 @@ const QString Searcher::getLastSearchPattern() const
 
 void Searcher::setLastSearchParams(const SearchParams &searchParams)
 {
-    m_lastSearchConfig = searchParams;
+    if (!searchParams.pattern.isEmpty())
+        m_lastSearchConfig = searchParams;
 }
 
 bool Searcher::lastSearchWrapped() const
@@ -80,17 +95,27 @@ Range Searcher::motionFindPrev(int count)
     return Range(match.endLine, match.endColumn - 1, ExclusiveMotion);
 }
 
-Range Searcher::findPatternForMotion(const SearchParams &searchParams, const KTextEditor::Cursor &startFrom, int count)
+Range Searcher::findPatternForMotion(const SearchParams &searchParams, const KTextEditor::Cursor startFrom, int count)
 {
     if (searchParams.pattern.isEmpty()) {
         return Range::invalid();
     }
 
     KTextEditor::Range match = findPatternWorker(searchParams, startFrom, count);
+
+    if (m_hlMode != HighlightMode::Disable) {
+        if (m_hlMode == HighlightMode::HideCurrent) {
+            m_hlMode = HighlightMode::Enable;
+            highlightVisibleResults(searchParams, true);
+        } else {
+            highlightVisibleResults(searchParams);
+        }
+    }
+
     return Range(match.start(), match.end(), ExclusiveMotion);
 }
 
-Range Searcher::findWordForMotion(const QString &word, bool backwards, const KTextEditor::Cursor &startFrom, int count)
+Range Searcher::findWordForMotion(const QString &word, bool backwards, const KTextEditor::Cursor startFrom, int count)
 {
     m_lastSearchConfig.isBackwards = backwards;
     m_lastSearchConfig.isCaseSensitive = false;
@@ -99,21 +124,154 @@ Range Searcher::findWordForMotion(const QString &word, bool backwards, const KTe
     m_viInputModeManager->globalState()->searchHistory()->append(QStringLiteral("\\<%1\\>").arg(word));
     QString pattern = QStringLiteral("\\b%1\\b").arg(word);
     m_lastSearchConfig.pattern = pattern;
+    if (m_hlMode == HighlightMode::HideCurrent)
+        m_hlMode = HighlightMode::Enable;
 
     return findPatternForMotion(m_lastSearchConfig, startFrom, count);
 }
 
-KTextEditor::Range Searcher::findPattern(const SearchParams &searchParams, const KTextEditor::Cursor &startFrom, int count, bool addToSearchHistory)
+KTextEditor::Range Searcher::findPattern(const SearchParams &searchParams, const KTextEditor::Cursor startFrom, int count, bool addToSearchHistory)
 {
     if (addToSearchHistory) {
         m_viInputModeManager->globalState()->searchHistory()->append(searchParams.pattern);
         m_lastSearchConfig = searchParams;
     }
 
-    return findPatternWorker(searchParams, startFrom, count);
+    KTextEditor::Range r = findPatternWorker(searchParams, startFrom, count);
+
+    if (m_hlMode != HighlightMode::Disable)
+        highlightVisibleResults(searchParams);
+
+    newPattern = false;
+    return r;
 }
 
-KTextEditor::Range Searcher::findPatternWorker(const SearchParams &searchParams, const KTextEditor::Cursor &startFrom, int count)
+void Searcher::highlightVisibleResults(const SearchParams &searchParams, bool force)
+{
+    if (newPattern && searchParams.pattern.isEmpty())
+        return;
+
+    auto vr = m_view->visibleRange();
+
+    const SearchParams &l = searchParams;
+    const SearchParams &r = m_lastHlSearchConfig;
+
+    if (!force && l.pattern == r.pattern && l.isCaseSensitive == r.isCaseSensitive && vr == m_lastHlSearchRange) {
+        return;
+    }
+
+    m_lastHlSearchConfig = searchParams;
+    m_lastHlSearchRange = vr;
+
+    clearHighlights();
+
+    KTextEditor::SearchOptions flags = KTextEditor::Regex;
+    m_lastSearchWrapped = false;
+
+    const QString &pattern = searchParams.pattern;
+
+    if (!searchParams.isCaseSensitive) {
+        flags |= KTextEditor::CaseInsensitive;
+    }
+
+    KTextEditor::Range match;
+    KTextEditor::Cursor current(vr.start());
+    KTextEditor::Cursor end(m_view->doc()->documentRange().end());
+
+    do {
+        match = m_view->doc()->searchText(KTextEditor::Range(current, vr.end()), pattern, flags).first();
+        if (match.isValid()) {
+            if (match.isEmpty())
+                match = KTextEditor::Range(match.start(), 1);
+
+            auto highlight = m_view->doc()->newMovingRange(match, Kate::TextRange::DoNotExpand);
+            highlight->setView(m_view);
+            highlight->setAttributeOnlyForViews(true);
+            highlight->setZDepth(-10000.0);
+            highlight->setAttribute(highlightMatchAttribute);
+            m_hlRanges.append(highlight);
+
+            current = match.end();
+        }
+    } while (match.isValid() && current < end);
+}
+
+void Searcher::clearHighlights()
+{
+    if (!m_hlRanges.empty()) {
+        qDeleteAll(m_hlRanges);
+        m_hlRanges.clear();
+    }
+}
+
+void Searcher::hideCurrentHighlight()
+{
+    if (m_hlMode != HighlightMode::Disable) {
+        m_hlMode = HighlightMode::HideCurrent;
+        clearHighlights();
+    }
+}
+
+void Searcher::updateHighlightColors()
+{
+    const QColor foregroundColor = m_view->defaultStyleAttribute(KTextEditor::dsNormal)->foreground().color();
+    const QColor &searchColor = m_view->renderer()->config()->searchHighlightColor();
+    // init match attribute
+    highlightMatchAttribute->setForeground(foregroundColor);
+    highlightMatchAttribute->setBackground(searchColor);
+}
+
+void Searcher::enableHighlightSearch(bool enable)
+{
+    if (enable) {
+        m_hlMode = HighlightMode::Enable;
+
+        connectDisplayRangeChanged();
+        highlightVisibleResults(m_lastSearchConfig, true);
+    } else {
+        m_hlMode = HighlightMode::Disable;
+
+        disconnectDisplayRangeChanged();
+        clearHighlights();
+    }
+}
+
+bool Searcher::isHighlightSearchEnabled() const
+{
+    return m_hlMode != HighlightMode::Disable;
+}
+
+void Searcher::disconnectDisplayRangeChanged()
+{
+    QObject::disconnect(m_displayRangeChangedConnection);
+}
+
+void Searcher::connectDisplayRangeChanged()
+{
+    disconnectDisplayRangeChanged();
+
+    m_displayRangeChangedConnection = QObject::connect(m_view, &KTextEditor::ViewPrivate::displayRangeChanged, [this]() {
+        if (m_hlMode == HighlightMode::Enable)
+            highlightVisibleResults(m_lastSearchConfig);
+    });
+}
+
+void Searcher::patternDone(bool wasAborted)
+{
+    if (wasAborted) {
+        if (m_hlMode == HighlightMode::HideCurrent || m_lastSearchConfig.pattern.isEmpty())
+            clearHighlights();
+        else if (m_hlMode == HighlightMode::Enable)
+            highlightVisibleResults(m_lastSearchConfig);
+
+    } else {
+        if (m_hlMode == HighlightMode::HideCurrent)
+            m_hlMode = HighlightMode::Enable;
+    }
+    newPattern = true;
+}
+
+KTextEditor::Range Searcher::findPatternWorker(const SearchParams &searchParams, const KTextEditor::Cursor startFrom, int count)
 {
     KTextEditor::Cursor searchBegin = startFrom;
     KTextEditor::SearchOptions flags = KTextEditor::Regex;
@@ -173,7 +331,7 @@ KTextEditor::Range Searcher::findPatternWorker(const SearchParams &searchParams,
                 std::sort(matchesUnfiltered.begin(), matchesUnfiltered.end());
 
                 QVector<KTextEditor::Range> filteredMatches;
-                for (KTextEditor::Range unfilteredMatch : qAsConst(matchesUnfiltered)) {
+                for (KTextEditor::Range unfilteredMatch : std::as_const(matchesUnfiltered)) {
                     if (unfilteredMatch.start() < searchBegin) {
                         filteredMatches.append(unfilteredMatch);
                     }
